/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.aggregates;

import java.util.Map;

import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

/**
 * An AggregateController is responsible for the registration of aggregates,
 * their pre- and post-processing.
 * 
 * @author Fabian Gorsler <fabian.gorsler@student.kit.edu>
 * 
 */
public interface AggregateController {

	/**
	 * Tests whether aggregates are registered
	 * 
	 * @return If true, aggregates are registered and processing is required
	 */
	public boolean hasAggregates();

	/**
	 * After the connector returns an EntityMapping a result, the aggregate
	 * values can be calculated and injected Probes can be removed from the
	 * response
	 * 
	 * @param response
	 *            The result of the query execution returned by the
	 *            corresponding connector
	 */
	public void postProcess(EntityMapping response);

	/**
	 * If aggregates have been registered, they must be pre-processed in order
	 * to ensure all requirements are met to calculate the aggregates after the
	 * query has been executed
	 * 
	 * @param request
	 *            The request to be sent to the query connector
	 * @param aliasMap
	 *            A map of metrics with aliased entities in the query
	 */
	public void preProcess(EntityMapping request, Map<String, Entity> aliasMap);

	/**
	 * Register an AggregateProcessor for an aggregate found in the query
	 * 
	 * @param processor
	 *            The AggregateProcessor to be registered
	 */
	public void registerAggregate(AggregateProcessor processor);

}
