/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.util;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.common.util.EList;

import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class EntityMappingHelper {

	/*
	 * Builds an index of entities using the identifier as key
	 */
	public static Map<String, Entity> buildEntityIndex(final EntityMapping response) {
		final int size = response.getEntities().size();
		final HashMap<String, Entity> index = new HashMap<String, Entity>(size);

		// Code doubling, but still more reasonable than copying both lists into
		// a temporary one first and then iterating over the list in a single
		// loop
		for (final Entity e : response.getEntities()) {
			index.put(e.getIdentifier(), e);
		}

		return index;
	}

	public static Map<String, Map<String, Probe>> buildProbeIndex(final EntityMapping mapping) {
		final int numEntities = mapping.getEntities().size();
		final Map<String, Map<String, Probe>> map = new HashMap<String, Map<String, Probe>>(numEntities);

		for (final Entity r : mapping.getEntities()) {
			map.put(r.getIdentifier(), EntityMappingHelper.indexProbes(r));
		}

		return map;
	}

	public static Map<String, Probe> indexProbes(final Entity entity) {
		final EList<Probe> probes = entity.getProbes();
		final Map<String, Probe> probeIndex = new HashMap<String, Probe>(probes.size());

		for (final Probe p : probes) {
			final String metricName = p.getMetricName();
			probeIndex.put(metricName, p);
		}

		return probeIndex;
	}

}
