/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.whatif;

import java.util.Iterator;

import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.Result;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class DoubleFilter implements WhatIfFilter {

	private boolean modifier;
	private double filteringDouble;

	public DoubleFilter(double filteringDouble, boolean modifier) {
		this.filteringDouble = filteringDouble;
		this.modifier = modifier;
	}

	@Override
	public EntityMapping applyFilter(final EntityMapping initial, final EntityMapping modified) {
		if (!initial.equals(modified)) { // else the initial gets modified and
											// looses all content
			// checking all Resouces
			for (Iterator<Entity> resourceIterator = modified.getEntities().iterator(); resourceIterator.hasNext();) {
				Entity resource = resourceIterator.next();
				for (Iterator<Probe> probeIterator = resource.getProbes().iterator(); probeIterator.hasNext();) {
					Probe probe = probeIterator.next();
					for (Iterator<StatType> statIterator = probe.getStatTypes().iterator(); statIterator.hasNext();) {
						StatType st = statIterator.next();
						Result r = st.getResult();
						if (r != null && r instanceof DecimalResult) {
							DecimalResult modifiedResult = (DecimalResult) r;
							DecimalResult initialResult = getResult(initial, resource.getIdentifier(),
									probe.getMetricName(), st.getTypeName());

							if (modifier) {
								if (filterWithModifier(modifiedResult, initialResult))
									statIterator.remove();
							} else if (filterWithoutModifier(modifiedResult, initialResult))
								statIterator.remove();
						}
					}
					if (probe.getStatTypes().isEmpty())
						probeIterator.remove();
				}
				if (resource.getProbes().isEmpty()) 
					resourceIterator.remove();
			}

			return modified;
		} else
			return initial;

	}

	private boolean filterWithoutModifier(final DecimalResult modifiedResult, final DecimalResult initialResult) {
		if (Math.abs(initialResult.getValue().doubleValue() - modifiedResult.getValue().doubleValue()) < filteringDouble)
			return true;
		else
			return false;
	}

	private boolean filterWithModifier(final DecimalResult modifiedResult, final DecimalResult initialResult) {
		double percent = Math.abs((modifiedResult.getValue().doubleValue() / initialResult.getValue().doubleValue()) - 1);
		if (percent < filteringDouble/100 || modifiedResult.getValue().intValue() == 0)
			return true;
		else
			return false;

	}

	private DecimalResult getResult(final EntityMapping initial, String identifier, String metricIdentifier,
			String string) {
		for (Iterator<Entity> resourceIterator = initial.getEntities().iterator(); resourceIterator.hasNext();) {
			Entity resource = resourceIterator.next();
			if (resource.getIdentifier().equals(identifier)) {
				for (Iterator<Probe> probeIterator = resource.getProbes().iterator(); probeIterator.hasNext();) {
					Probe probe = probeIterator.next();
					if (probe.getMetricName().equals(metricIdentifier)) {
						for (StatType st: probe.getStatTypes())
							if (st.getTypeName().equals(string))
								return (DecimalResult) st.getResult();
					}
				}
			}
		}
		return null;
	}

}
