/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.whatif;

import java.util.Iterator;

import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class ZeroFilter implements WhatIfFilter {

	public ZeroFilter() {

	}

	@Override
	public EntityMapping applyFilter(EntityMapping initial, EntityMapping modified) {
		if (!initial.equals(modified)) { // else the initial gets modified and
											// looses all content

			// checking all Resources
			for (Iterator<Entity> resourceIterator = modified.getEntities().iterator(); resourceIterator.hasNext();) {
				Entity resource = resourceIterator.next();
				for (Iterator<Probe> probeIterator = resource.getProbes().iterator(); probeIterator.hasNext();) {
					Probe probe = probeIterator.next();
					for (Iterator<StatType> stIterator = probe.getStatTypes().iterator(); stIterator.hasNext();) {
						StatType st = stIterator.next();
						if (st.getResult() instanceof DecimalResult) {
							DecimalResult modifiedResult = (DecimalResult) st.getResult();
							if (modifiedResult.getValue().intValue() == 0)
								stIterator.remove();
						}
					}
					if (resource.getProbes().isEmpty())
						resourceIterator.remove();
				}
			}
			return modified;
		} else
			return initial;

	}

}
