/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.ui.contentassist.antlr;

import java.util.Collection;
import java.util.Map;
import java.util.HashMap;

import org.antlr.runtime.RecognitionException;
import org.eclipse.xtext.AbstractElement;
import org.eclipse.xtext.ui.editor.contentassist.antlr.AbstractContentAssistParser;
import org.eclipse.xtext.ui.editor.contentassist.antlr.FollowElement;
import org.eclipse.xtext.ui.editor.contentassist.antlr.internal.AbstractInternalContentAssistParser;

import com.google.inject.Inject;

import tools.descartes.dql.lang.services.DescartesQLGrammarAccess;

public class DescartesQLParser extends AbstractContentAssistParser {
	
	@Inject
	private DescartesQLGrammarAccess grammarAccess;
	
	private Map<AbstractElement, String> nameMappings;
	
	@Override
	protected tools.descartes.dql.lang.ui.contentassist.antlr.internal.InternalDescartesQLParser createParser() {
		tools.descartes.dql.lang.ui.contentassist.antlr.internal.InternalDescartesQLParser result = new tools.descartes.dql.lang.ui.contentassist.antlr.internal.InternalDescartesQLParser(null);
		result.setGrammarAccess(grammarAccess);
		return result;
	}
	
	@Override
	protected String getRuleName(AbstractElement element) {
		if (nameMappings == null) {
			nameMappings = new HashMap<AbstractElement, String>() {
				private static final long serialVersionUID = 1L;
				{
					put(grammarAccess.getDescartesQLAccess().getQueryAlternatives_0_0(), "rule__DescartesQL__QueryAlternatives_0_0");
					put(grammarAccess.getGoalAccess().getQueryTypeAlternatives_0_0(), "rule__Goal__QueryTypeAlternatives_0_0");
					put(grammarAccess.getListQueryAccess().getQueryTypeAlternatives_1_0(), "rule__ListQuery__QueryTypeAlternatives_1_0");
					put(grammarAccess.getGetQueryAccess().getQueryTapeAlternatives_1_0(), "rule__GetQuery__QueryTapeAlternatives_1_0");
					put(grammarAccess.getMetricClauseTypeAccess().getAlternatives(), "rule__MetricClauseType__Alternatives");
					put(grammarAccess.getDoFVariationClauseAccess().getVariationAlternatives_1_0(), "rule__DoFVariationClause__VariationAlternatives_1_0");
					put(grammarAccess.getDoFReferenceAccess().getDoFVariationClauseAlternatives_2_0(), "rule__DoFReference__DoFVariationClauseAlternatives_2_0");
					put(grammarAccess.getAggregateMetricClauseAccess().getMetricsAlternatives_2_0(), "rule__AggregateMetricClause__MetricsAlternatives_2_0");
					put(grammarAccess.getNavigationClauseAccess().getAlternatives(), "rule__NavigationClause__Alternatives");
					put(grammarAccess.getObservationClauseAccess().getAlternatives(), "rule__ObservationClause__Alternatives");
					put(grammarAccess.getObserveRelativeClauseAccess().getTimeTargetAlternatives_1_0(), "rule__ObserveRelativeClause__TimeTargetAlternatives_1_0");
					put(grammarAccess.getObserveBetweenClauseAccess().getStartingTimeAlternatives_1_0(), "rule__ObserveBetweenClause__StartingTimeAlternatives_1_0");
					put(grammarAccess.getObserveBetweenClauseAccess().getEndingTimeAlternatives_3_0(), "rule__ObserveBetweenClause__EndingTimeAlternatives_3_0");
					put(grammarAccess.getBetweenTimeClauseAccess().getAlternatives(), "rule__BetweenTimeClause__Alternatives");
					put(grammarAccess.getTimeClauseAccess().getAlternatives(), "rule__TimeClause__Alternatives");
					put(grammarAccess.getFilteringClauseAccess().getAlternatives_1(), "rule__FilteringClause__Alternatives_1");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseAlternatives_1_0(), "rule__WhatIfValueVariationClause__VariationClauseAlternatives_1_0");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseAlternatives_2_1_0(), "rule__WhatIfValueVariationClause__VariationClauseAlternatives_2_1_0");
					put(grammarAccess.getArithmeticClauseAccess().getModeAlternatives_0_0(), "rule__ArithmeticClause__ModeAlternatives_0_0");
					put(grammarAccess.getVariableValueAccess().getAlternatives(), "rule__VariableValue__Alternatives");
					put(grammarAccess.getComparatorAccess().getAlternatives(), "rule__Comparator__Alternatives");
					put(grammarAccess.getCurrencyAccess().getAlternatives(), "rule__Currency__Alternatives");
					put(grammarAccess.getFilterConjunctionAccess().getAlternatives(), "rule__FilterConjunction__Alternatives");
					put(grammarAccess.getFilterConditionTypeAccess().getAlternatives(), "rule__FilterConditionType__Alternatives");
					put(grammarAccess.getObserveRelativeDirectionTypeAccess().getAlternatives(), "rule__ObserveRelativeDirectionType__Alternatives");
					put(grammarAccess.getRelativeTimeSignTypeAccess().getAlternatives(), "rule__RelativeTimeSignType__Alternatives");
					put(grammarAccess.getTimeModifierTypeAccess().getAlternatives(), "rule__TimeModifierType__Alternatives");
					put(grammarAccess.getStatisticalAggregateTypeAccess().getAlternatives(), "rule__StatisticalAggregateType__Alternatives");
					put(grammarAccess.getDescartesQLAccess().getGroup(), "rule__DescartesQL__Group__0");
					put(grammarAccess.getGoalAccess().getGroup(), "rule__Goal__Group__0");
					put(grammarAccess.getSlaQueryAccess().getGroup(), "rule__SlaQuery__Group__0");
					put(grammarAccess.getSlaQueryAccess().getGroup_2(), "rule__SlaQuery__Group_2__0");
					put(grammarAccess.getSloQueryAccess().getGroup(), "rule__SloQuery__Group__0");
					put(grammarAccess.getSloQueryAccess().getGroup_2(), "rule__SloQuery__Group_2__0");
					put(grammarAccess.getSlaAccess().getGroup(), "rule__Sla__Group__0");
					put(grammarAccess.getSlaAccess().getGroup_4(), "rule__Sla__Group_4__0");
					put(grammarAccess.getSloAccess().getGroup(), "rule__Slo__Group__0");
					put(grammarAccess.getWeightedSloAccess().getGroup(), "rule__WeightedSlo__Group__0");
					put(grammarAccess.getWeightedSloAccess().getGroup_1(), "rule__WeightedSlo__Group_1__0");
					put(grammarAccess.getFuzzinessAccess().getGroup(), "rule__Fuzziness__Group__0");
					put(grammarAccess.getPenaltyAccess().getGroup(), "rule__Penalty__Group__0");
					put(grammarAccess.getViolationAccess().getGroup(), "rule__Violation__Group__0");
					put(grammarAccess.getListQueryAccess().getGroup(), "rule__ListQuery__Group__0");
					put(grammarAccess.getGetQueryAccess().getGroup(), "rule__GetQuery__Group__0");
					put(grammarAccess.getListDoFQueryAccess().getGroup(), "rule__ListDoFQuery__Group__0");
					put(grammarAccess.getListMetricsQueryAccess().getGroup(), "rule__ListMetricsQuery__Group__0");
					put(grammarAccess.getSelectQueryAccess().getGroup(), "rule__SelectQuery__Group__0");
					put(grammarAccess.getMetricReferenceClausesAccess().getGroup(), "rule__MetricReferenceClauses__Group__0");
					put(grammarAccess.getMetricReferenceClausesAccess().getGroup_1(), "rule__MetricReferenceClauses__Group_1__0");
					put(grammarAccess.getDetectQueryAccess().getGroup(), "rule__DetectQuery__Group__0");
					put(grammarAccess.getDetectBottlenecksQueryAccess().getGroup(), "rule__DetectBottlenecksQuery__Group__0");
					put(grammarAccess.getConstraintClauseAccess().getGroup(), "rule__ConstraintClause__Group__0");
					put(grammarAccess.getDoFClauseAccess().getGroup(), "rule__DoFClause__Group__0");
					put(grammarAccess.getExplorationStrategyClauseAccess().getGroup(), "rule__ExplorationStrategyClause__Group__0");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getGroup(), "rule__ConfigurationPropertiesClause__Group__0");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getGroup_2(), "rule__ConfigurationPropertiesClause__Group_2__0");
					put(grammarAccess.getConfigurationPropertyClauseAccess().getGroup(), "rule__ConfigurationPropertyClause__Group__0");
					put(grammarAccess.getConfigurationPropertyClauseAccess().getGroup_1(), "rule__ConfigurationPropertyClause__Group_1__0");
					put(grammarAccess.getDoFVariationClauseAccess().getGroup(), "rule__DoFVariationClause__Group__0");
					put(grammarAccess.getValueVariationClauseAccess().getGroup(), "rule__ValueVariationClause__Group__0");
					put(grammarAccess.getValueVariationClauseAccess().getGroup_1(), "rule__ValueVariationClause__Group_1__0");
					put(grammarAccess.getDoubleValueVariationClauseAccess().getGroup(), "rule__DoubleValueVariationClause__Group__0");
					put(grammarAccess.getDoubleValueVariationClauseAccess().getGroup_1(), "rule__DoubleValueVariationClause__Group_1__0");
					put(grammarAccess.getIntervalVariationClauseAccess().getGroup(), "rule__IntervalVariationClause__Group__0");
					put(grammarAccess.getVaryingClauseAccess().getGroup(), "rule__VaryingClause__Group__0");
					put(grammarAccess.getVaryingClauseAccess().getGroup_2(), "rule__VaryingClause__Group_2__0");
					put(grammarAccess.getDoFReferenceAccess().getGroup(), "rule__DoFReference__Group__0");
					put(grammarAccess.getAggregateMetricClauseAccess().getGroup(), "rule__AggregateMetricClause__Group__0");
					put(grammarAccess.getMetricClausesAccess().getGroup(), "rule__MetricClauses__Group__0");
					put(grammarAccess.getMetricClausesAccess().getGroup_1(), "rule__MetricClauses__Group_1__0");
					put(grammarAccess.getMetricStarClauseAccess().getGroup(), "rule__MetricStarClause__Group__0");
					put(grammarAccess.getMetricReferenceAccess().getGroup(), "rule__MetricReference__Group__0");
					put(grammarAccess.getMetricReferenceAccess().getGroup_1(), "rule__MetricReference__Group_1__0");
					put(grammarAccess.getMetricReferenceAccess().getGroup_4(), "rule__MetricReference__Group_4__0");
					put(grammarAccess.getFindClauseAccess().getGroup(), "rule__FindClause__Group__0");
					put(grammarAccess.getForClauseAccess().getGroup(), "rule__ForClause__Group__0");
					put(grammarAccess.getEntityReferenceClauseAccess().getGroup(), "rule__EntityReferenceClause__Group__0");
					put(grammarAccess.getEntityReferenceClauseAccess().getGroup_1(), "rule__EntityReferenceClause__Group_1__0");
					put(grammarAccess.getEntityReferenceAccess().getGroup(), "rule__EntityReference__Group__0");
					put(grammarAccess.getAliasClauseAccess().getGroup(), "rule__AliasClause__Group__0");
					put(grammarAccess.getUsingClauseAccess().getGroup(), "rule__UsingClause__Group__0");
					put(grammarAccess.getWithClauseAccess().getGroup(), "rule__WithClause__Group__0");
					put(grammarAccess.getModelReferenceClauseAccess().getGroup(), "rule__ModelReferenceClause__Group__0");
					put(grammarAccess.getFilterClauseAccess().getGroup(), "rule__FilterClause__Group__0");
					put(grammarAccess.getFilterClauseAccess().getGroup_2(), "rule__FilterClause__Group_2__0");
					put(grammarAccess.getFilterConditionClauseAccess().getGroup(), "rule__FilterConditionClause__Group__0");
					put(grammarAccess.getObserveClauseAccess().getGroup(), "rule__ObserveClause__Group__0");
					put(grammarAccess.getSampleClauseAccess().getGroup(), "rule__SampleClause__Group__0");
					put(grammarAccess.getConnectorTimeUnitClauseAccess().getGroup(), "rule__ConnectorTimeUnitClause__Group__0");
					put(grammarAccess.getConnectorInstanceReferenceClauseAccess().getGroup(), "rule__ConnectorInstanceReferenceClause__Group__0");
					put(grammarAccess.getObserveRelativeClauseAccess().getGroup(), "rule__ObserveRelativeClause__Group__0");
					put(grammarAccess.getObserveBetweenClauseAccess().getGroup(), "rule__ObserveBetweenClause__Group__0");
					put(grammarAccess.getRelativeTimeWithSignClauseAccess().getGroup(), "rule__RelativeTimeWithSignClause__Group__0");
					put(grammarAccess.getRelativeTimeClauseAccess().getGroup(), "rule__RelativeTimeClause__Group__0");
					put(grammarAccess.getRelativeTimeDurationClauseAccess().getGroup(), "rule__RelativeTimeDurationClause__Group__0");
					put(grammarAccess.getWhatIfQueryAccess().getGroup(), "rule__WhatIfQuery__Group__0");
					put(grammarAccess.getWhatIfQueryAccess().getGroup_2(), "rule__WhatIfQuery__Group_2__0");
					put(grammarAccess.getWhatIfVariationAccess().getGroup(), "rule__WhatIfVariation__Group__0");
					put(grammarAccess.getWhatIfVariationAccess().getGroup_1(), "rule__WhatIfVariation__Group_1__0");
					put(grammarAccess.getFilteringClauseAccess().getGroup(), "rule__FilteringClause__Group__0");
					put(grammarAccess.getFilteringRuleAccess().getGroup(), "rule__FilteringRule__Group__0");
					put(grammarAccess.getWhatIfVariationClauseAccess().getGroup(), "rule__WhatIfVariationClause__Group__0");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getGroup(), "rule__WhatIfValueVariationClause__Group__0");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getGroup_2(), "rule__WhatIfValueVariationClause__Group_2__0");
					put(grammarAccess.getMultipleVariationInstructionAccess().getGroup(), "rule__MultipleVariationInstruction__Group__0");
					put(grammarAccess.getMultipleVariationInstructionAccess().getGroup_2(), "rule__MultipleVariationInstruction__Group_2__0");
					put(grammarAccess.getVariationInstructionAccess().getGroup(), "rule__VariationInstruction__Group__0");
					put(grammarAccess.getVariationInstructionAccess().getGroup_1(), "rule__VariationInstruction__Group_1__0");
					put(grammarAccess.getMultipleArithmeticClauseAccess().getGroup(), "rule__MultipleArithmeticClause__Group__0");
					put(grammarAccess.getMultipleArithmeticClauseAccess().getGroup_2(), "rule__MultipleArithmeticClause__Group_2__0");
					put(grammarAccess.getArithmeticClauseAccess().getGroup(), "rule__ArithmeticClause__Group__0");
					put(grammarAccess.getDescartesQLAccess().getQueryAssignment_0(), "rule__DescartesQL__QueryAssignment_0");
					put(grammarAccess.getGoalAccess().getQueryTypeAssignment_0(), "rule__Goal__QueryTypeAssignment_0");
					put(grammarAccess.getGoalAccess().getSlaQueryAssignment_1(), "rule__Goal__SlaQueryAssignment_1");
					put(grammarAccess.getGoalAccess().getSloQueryAssignment_2(), "rule__Goal__SloQueryAssignment_2");
					put(grammarAccess.getGoalAccess().getConstraintClauseAssignment_3(), "rule__Goal__ConstraintClauseAssignment_3");
					put(grammarAccess.getGoalAccess().getDofClauseAssignment_4(), "rule__Goal__DofClauseAssignment_4");
					put(grammarAccess.getGoalAccess().getForClauseAssignment_5(), "rule__Goal__ForClauseAssignment_5");
					put(grammarAccess.getGoalAccess().getUsingClauseAssignment_6(), "rule__Goal__UsingClauseAssignment_6");
					put(grammarAccess.getSlaQueryAccess().getTypeAssignment_0(), "rule__SlaQuery__TypeAssignment_0");
					put(grammarAccess.getSlaQueryAccess().getSlasAssignment_1(), "rule__SlaQuery__SlasAssignment_1");
					put(grammarAccess.getSlaQueryAccess().getSlasAssignment_2_1(), "rule__SlaQuery__SlasAssignment_2_1");
					put(grammarAccess.getSloQueryAccess().getTypeAssignment_0(), "rule__SloQuery__TypeAssignment_0");
					put(grammarAccess.getSloQueryAccess().getSlosAssignment_1(), "rule__SloQuery__SlosAssignment_1");
					put(grammarAccess.getSloQueryAccess().getSlosAssignment_2_1(), "rule__SloQuery__SlosAssignment_2_1");
					put(grammarAccess.getSlaAccess().getNameAssignment_0(), "rule__Sla__NameAssignment_0");
					put(grammarAccess.getSlaAccess().getWeightedSloAssignment_3(), "rule__Sla__WeightedSloAssignment_3");
					put(grammarAccess.getSlaAccess().getWeightedSloAssignment_4_1(), "rule__Sla__WeightedSloAssignment_4_1");
					put(grammarAccess.getSloAccess().getNameAssignment_0(), "rule__Slo__NameAssignment_0");
					put(grammarAccess.getSloAccess().getMetricClauseTypeAssignment_2(), "rule__Slo__MetricClauseTypeAssignment_2");
					put(grammarAccess.getSloAccess().getComparatorAssignment_3(), "rule__Slo__ComparatorAssignment_3");
					put(grammarAccess.getSloAccess().getValueAssignment_4(), "rule__Slo__ValueAssignment_4");
					put(grammarAccess.getSloAccess().getFuzAssignment_5(), "rule__Slo__FuzAssignment_5");
					put(grammarAccess.getSloAccess().getPenAssignment_6(), "rule__Slo__PenAssignment_6");
					put(grammarAccess.getWeightedSloAccess().getSloAssignment_0(), "rule__WeightedSlo__SloAssignment_0");
					put(grammarAccess.getWeightedSloAccess().getWeightAssignment_1_1(), "rule__WeightedSlo__WeightAssignment_1_1");
					put(grammarAccess.getFuzzinessAccess().getTypeAssignment_0(), "rule__Fuzziness__TypeAssignment_0");
					put(grammarAccess.getFuzzinessAccess().getDeviationAssignment_1(), "rule__Fuzziness__DeviationAssignment_1");
					put(grammarAccess.getPenaltyAccess().getTypeAssignment_0(), "rule__Penalty__TypeAssignment_0");
					put(grammarAccess.getPenaltyAccess().getValueAssignment_1(), "rule__Penalty__ValueAssignment_1");
					put(grammarAccess.getPenaltyAccess().getCurrencyAssignment_2(), "rule__Penalty__CurrencyAssignment_2");
					put(grammarAccess.getPenaltyAccess().getViolationAssignment_3(), "rule__Penalty__ViolationAssignment_3");
					put(grammarAccess.getViolationAccess().getAmountAssignment_1(), "rule__Violation__AmountAssignment_1");
					put(grammarAccess.getListQueryAccess().getQueryTypeAssignment_1(), "rule__ListQuery__QueryTypeAssignment_1");
					put(grammarAccess.getListQueryAccess().getFilterClauseAssignment_2(), "rule__ListQuery__FilterClauseAssignment_2");
					put(grammarAccess.getListQueryAccess().getUsingClauseAssignment_3(), "rule__ListQuery__UsingClauseAssignment_3");
					put(grammarAccess.getGetQueryAccess().getQueryTapeAssignment_1(), "rule__GetQuery__QueryTapeAssignment_1");
					put(grammarAccess.getGetQueryAccess().getUsingClauseAssignment_2(), "rule__GetQuery__UsingClauseAssignment_2");
					put(grammarAccess.getGetConstraintsQueryAccess().getModeAssignment(), "rule__GetConstraintsQuery__ModeAssignment");
					put(grammarAccess.getGetExplorationStrategiesQueryAccess().getModeAssignment(), "rule__GetExplorationStrategiesQuery__ModeAssignment");
					put(grammarAccess.getGetTimeUnitsQueryAccess().getModeAssignment(), "rule__GetTimeUnitsQuery__ModeAssignment");
					put(grammarAccess.getListDoFQueryAccess().getModeAssignment_0(), "rule__ListDoFQuery__ModeAssignment_0");
					put(grammarAccess.getListDoFQueryAccess().getWithClauseAssignment_1(), "rule__ListDoFQuery__WithClauseAssignment_1");
					put(grammarAccess.getListEntitiesQueryAccess().getModeAssignment(), "rule__ListEntitiesQuery__ModeAssignment");
					put(grammarAccess.getListMetricsQueryAccess().getModeAssignment_0(), "rule__ListMetricsQuery__ModeAssignment_0");
					put(grammarAccess.getListMetricsQueryAccess().getEntityReferenceClauseAssignment_2(), "rule__ListMetricsQuery__EntityReferenceClauseAssignment_2");
					put(grammarAccess.getSelectQueryAccess().getMetricReferenceClausesAssignment_1(), "rule__SelectQuery__MetricReferenceClausesAssignment_1");
					put(grammarAccess.getSelectQueryAccess().getConstraintClauseAssignment_2(), "rule__SelectQuery__ConstraintClauseAssignment_2");
					put(grammarAccess.getSelectQueryAccess().getDofClauseAssignment_3(), "rule__SelectQuery__DofClauseAssignment_3");
					put(grammarAccess.getSelectQueryAccess().getForClauseAssignment_4(), "rule__SelectQuery__ForClauseAssignment_4");
					put(grammarAccess.getSelectQueryAccess().getUsingClauseAssignment_5(), "rule__SelectQuery__UsingClauseAssignment_5");
					put(grammarAccess.getSelectQueryAccess().getObserveClauseAssignment_6(), "rule__SelectQuery__ObserveClauseAssignment_6");
					put(grammarAccess.getMetricReferenceClausesAccess().getMetricClauseTypesAssignment_0(), "rule__MetricReferenceClauses__MetricClauseTypesAssignment_0");
					put(grammarAccess.getMetricReferenceClausesAccess().getMetricClauseTypesAssignment_1_1(), "rule__MetricReferenceClauses__MetricClauseTypesAssignment_1_1");
					put(grammarAccess.getDetectQueryAccess().getQueryTypeAssignment_1(), "rule__DetectQuery__QueryTypeAssignment_1");
					put(grammarAccess.getDetectBottlenecksQueryAccess().getDofClauseAssignment_1(), "rule__DetectBottlenecksQuery__DofClauseAssignment_1");
					put(grammarAccess.getDetectBottlenecksQueryAccess().getUsingClauseAssignment_2(), "rule__DetectBottlenecksQuery__UsingClauseAssignment_2");
					put(grammarAccess.getConstraintClauseAccess().getTypeAssignment_1(), "rule__ConstraintClause__TypeAssignment_1");
					put(grammarAccess.getDoFClauseAccess().getModeAssignment_0(), "rule__DoFClause__ModeAssignment_0");
					put(grammarAccess.getDoFClauseAccess().getVaryingClauseAssignment_1(), "rule__DoFClause__VaryingClauseAssignment_1");
					put(grammarAccess.getDoFClauseAccess().getExplorationStrategyAssignment_2(), "rule__DoFClause__ExplorationStrategyAssignment_2");
					put(grammarAccess.getDoFClauseAccess().getConstraintClauseAssignment_3(), "rule__DoFClause__ConstraintClauseAssignment_3");
					put(grammarAccess.getDoFClauseAccess().getWithClauseAssignment_4(), "rule__DoFClause__WithClauseAssignment_4");
					put(grammarAccess.getExplorationStrategyClauseAccess().getModeAssignment_0(), "rule__ExplorationStrategyClause__ModeAssignment_0");
					put(grammarAccess.getExplorationStrategyClauseAccess().getNameAssignment_1(), "rule__ExplorationStrategyClause__NameAssignment_1");
					put(grammarAccess.getExplorationStrategyClauseAccess().getParameterClauseAssignment_2(), "rule__ExplorationStrategyClause__ParameterClauseAssignment_2");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getMode1Assignment_0(), "rule__ConfigurationPropertiesClause__Mode1Assignment_0");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getPropertiesAssignment_1(), "rule__ConfigurationPropertiesClause__PropertiesAssignment_1");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getPropertiesAssignment_2_1(), "rule__ConfigurationPropertiesClause__PropertiesAssignment_2_1");
					put(grammarAccess.getConfigurationPropertiesClauseAccess().getMode2Assignment_3(), "rule__ConfigurationPropertiesClause__Mode2Assignment_3");
					put(grammarAccess.getConfigurationPropertyClauseAccess().getKeyAssignment_0(), "rule__ConfigurationPropertyClause__KeyAssignment_0");
					put(grammarAccess.getConfigurationPropertyClauseAccess().getKeyAssignment_1_1(), "rule__ConfigurationPropertyClause__KeyAssignment_1_1");
					put(grammarAccess.getConfigurationPropertyClauseAccess().getValueAssignment_3(), "rule__ConfigurationPropertyClause__ValueAssignment_3");
					put(grammarAccess.getDoFVariationClauseAccess().getMode1Assignment_0(), "rule__DoFVariationClause__Mode1Assignment_0");
					put(grammarAccess.getDoFVariationClauseAccess().getVariationAssignment_1(), "rule__DoFVariationClause__VariationAssignment_1");
					put(grammarAccess.getDoFVariationClauseAccess().getMode2Assignment_2(), "rule__DoFVariationClause__Mode2Assignment_2");
					put(grammarAccess.getValueVariationClauseAccess().getValueAssignment_0(), "rule__ValueVariationClause__ValueAssignment_0");
					put(grammarAccess.getValueVariationClauseAccess().getValueAssignment_1_1(), "rule__ValueVariationClause__ValueAssignment_1_1");
					put(grammarAccess.getDoubleValueVariationClauseAccess().getValueAssignment_0(), "rule__DoubleValueVariationClause__ValueAssignment_0");
					put(grammarAccess.getDoubleValueVariationClauseAccess().getValueAssignment_1_1(), "rule__DoubleValueVariationClause__ValueAssignment_1_1");
					put(grammarAccess.getIntervalVariationClauseAccess().getStartAssignment_0(), "rule__IntervalVariationClause__StartAssignment_0");
					put(grammarAccess.getIntervalVariationClauseAccess().getEndAssignment_2(), "rule__IntervalVariationClause__EndAssignment_2");
					put(grammarAccess.getIntervalVariationClauseAccess().getStepAssignment_4(), "rule__IntervalVariationClause__StepAssignment_4");
					put(grammarAccess.getVaryingClauseAccess().getModeAssignment_0(), "rule__VaryingClause__ModeAssignment_0");
					put(grammarAccess.getVaryingClauseAccess().getDofReferencesAssignment_1(), "rule__VaryingClause__DofReferencesAssignment_1");
					put(grammarAccess.getVaryingClauseAccess().getDofReferencesAssignment_2_1(), "rule__VaryingClause__DofReferencesAssignment_2_1");
					put(grammarAccess.getDoFReferenceAccess().getDoFIdentifierAssignment_0(), "rule__DoFReference__DoFIdentifierAssignment_0");
					put(grammarAccess.getDoFReferenceAccess().getDoFAliasClauseAssignment_1(), "rule__DoFReference__DoFAliasClauseAssignment_1");
					put(grammarAccess.getDoFReferenceAccess().getDoFVariationClauseAssignment_2(), "rule__DoFReference__DoFVariationClauseAssignment_2");
					put(grammarAccess.getMetricClauseAccess().getMetricReferenceAssignment(), "rule__MetricClause__MetricReferenceAssignment");
					put(grammarAccess.getAggregateMetricClauseAccess().getFunctionAssignment_0(), "rule__AggregateMetricClause__FunctionAssignment_0");
					put(grammarAccess.getAggregateMetricClauseAccess().getMetricsAssignment_2(), "rule__AggregateMetricClause__MetricsAssignment_2");
					put(grammarAccess.getAggregateMetricClauseAccess().getPropertiesAssignment_4(), "rule__AggregateMetricClause__PropertiesAssignment_4");
					put(grammarAccess.getMetricClausesAccess().getMetricsAssignment_0(), "rule__MetricClauses__MetricsAssignment_0");
					put(grammarAccess.getMetricClausesAccess().getMetricsAssignment_1_1(), "rule__MetricClauses__MetricsAssignment_1_1");
					put(grammarAccess.getMetricStarClauseAccess().getMetricNameAssignment_1(), "rule__MetricStarClause__MetricNameAssignment_1");
					put(grammarAccess.getMetricReferenceAccess().getEntityReferenceAssignment_0(), "rule__MetricReference__EntityReferenceAssignment_0");
					put(grammarAccess.getMetricReferenceAccess().getSeperatornAssignment_1_0(), "rule__MetricReference__SeperatornAssignment_1_0");
					put(grammarAccess.getMetricReferenceAccess().getNavigationClauseAssignment_1_1(), "rule__MetricReference__NavigationClauseAssignment_1_1");
					put(grammarAccess.getMetricReferenceAccess().getSeparatorAssignment_2(), "rule__MetricReference__SeparatorAssignment_2");
					put(grammarAccess.getMetricReferenceAccess().getMetricReferenceAssignment_3(), "rule__MetricReference__MetricReferenceAssignment_3");
					put(grammarAccess.getMetricReferenceAccess().getSeparatorvAssignment_4_0(), "rule__MetricReference__SeparatorvAssignment_4_0");
					put(grammarAccess.getMetricReferenceAccess().getStatTypeReferenceAssignment_4_1(), "rule__MetricReference__StatTypeReferenceAssignment_4_1");
					put(grammarAccess.getChildrenClauseAccess().getContentAssignment(), "rule__ChildrenClause__ContentAssignment");
					put(grammarAccess.getParentClauseAccess().getContentAssignment(), "rule__ParentClause__ContentAssignment");
					put(grammarAccess.getFindClauseAccess().getStartAssignment_0(), "rule__FindClause__StartAssignment_0");
					put(grammarAccess.getFindClauseAccess().getChildNameAssignment_1(), "rule__FindClause__ChildNameAssignment_1");
					put(grammarAccess.getFindClauseAccess().getEndAssignment_2(), "rule__FindClause__EndAssignment_2");
					put(grammarAccess.getForClauseAccess().getModeAssignment_0(), "rule__ForClause__ModeAssignment_0");
					put(grammarAccess.getForClauseAccess().getEntityReferenceClauseAssignment_1(), "rule__ForClause__EntityReferenceClauseAssignment_1");
					put(grammarAccess.getEntityReferenceClauseAccess().getEntityReferencesAssignment_0(), "rule__EntityReferenceClause__EntityReferencesAssignment_0");
					put(grammarAccess.getEntityReferenceClauseAccess().getEntityReferencesAssignment_1_1(), "rule__EntityReferenceClause__EntityReferencesAssignment_1_1");
					put(grammarAccess.getEntityReferenceAccess().getTypeAssignment_0(), "rule__EntityReference__TypeAssignment_0");
					put(grammarAccess.getEntityReferenceAccess().getIdentifierAssignment_1(), "rule__EntityReference__IdentifierAssignment_1");
					put(grammarAccess.getEntityReferenceAccess().getAliasAssignment_2(), "rule__EntityReference__AliasAssignment_2");
					put(grammarAccess.getAliasClauseAccess().getModeAssignment_0(), "rule__AliasClause__ModeAssignment_0");
					put(grammarAccess.getAliasClauseAccess().getAliasAssignment_1(), "rule__AliasClause__AliasAssignment_1");
					put(grammarAccess.getUsingClauseAccess().getModeAssignment_0(), "rule__UsingClause__ModeAssignment_0");
					put(grammarAccess.getUsingClauseAccess().getModelReferenceAssignment_1(), "rule__UsingClause__ModelReferenceAssignment_1");
					put(grammarAccess.getWithClauseAccess().getModeAssignment_0(), "rule__WithClause__ModeAssignment_0");
					put(grammarAccess.getWithClauseAccess().getModelReferenceAssignment_1(), "rule__WithClause__ModelReferenceAssignment_1");
					put(grammarAccess.getModelReferenceClauseAccess().getFamilyAssignment_0(), "rule__ModelReferenceClause__FamilyAssignment_0");
					put(grammarAccess.getModelReferenceClauseAccess().getModelAssignment_2(), "rule__ModelReferenceClause__ModelAssignment_2");
					put(grammarAccess.getModelFamilyAccess().getFamilyAssignment(), "rule__ModelFamily__FamilyAssignment");
					put(grammarAccess.getModelLocationAccess().getLocationAssignment(), "rule__ModelLocation__LocationAssignment");
					put(grammarAccess.getFilterClauseAccess().getModeAssignment_0(), "rule__FilterClause__ModeAssignment_0");
					put(grammarAccess.getFilterClauseAccess().getFilterConditionsAssignment_1(), "rule__FilterClause__FilterConditionsAssignment_1");
					put(grammarAccess.getFilterClauseAccess().getFilterConjunctionsAssignment_2_0(), "rule__FilterClause__FilterConjunctionsAssignment_2_0");
					put(grammarAccess.getFilterClauseAccess().getFilterConditionsAssignment_2_1(), "rule__FilterClause__FilterConditionsAssignment_2_1");
					put(grammarAccess.getFilterConditionClauseAccess().getModeAssignment_0(), "rule__FilterConditionClause__ModeAssignment_0");
					put(grammarAccess.getFilterConditionClauseAccess().getConditionAssignment_2(), "rule__FilterConditionClause__ConditionAssignment_2");
					put(grammarAccess.getFilterConditionClauseAccess().getValueAssignment_4(), "rule__FilterConditionClause__ValueAssignment_4");
					put(grammarAccess.getFilterConditionValueAccess().getValueAssignment(), "rule__FilterConditionValue__ValueAssignment");
					put(grammarAccess.getObserveClauseAccess().getModeAssignment_0(), "rule__ObserveClause__ModeAssignment_0");
					put(grammarAccess.getObserveClauseAccess().getObservationAssignment_1(), "rule__ObserveClause__ObservationAssignment_1");
					put(grammarAccess.getObserveClauseAccess().getSampleClauseAssignment_2(), "rule__ObserveClause__SampleClauseAssignment_2");
					put(grammarAccess.getSampleClauseAccess().getModeAssignment_0(), "rule__SampleClause__ModeAssignment_0");
					put(grammarAccess.getSampleClauseAccess().getDurationClauseAssignment_1(), "rule__SampleClause__DurationClauseAssignment_1");
					put(grammarAccess.getSampleClauseAccess().getDurationClauseAssignment_2(), "rule__SampleClause__DurationClauseAssignment_2");
					put(grammarAccess.getConnectorTimeUnitClauseAccess().getCountAssignment_0(), "rule__ConnectorTimeUnitClause__CountAssignment_0");
					put(grammarAccess.getConnectorTimeUnitClauseAccess().getTimeIndicatorAssignment_1(), "rule__ConnectorTimeUnitClause__TimeIndicatorAssignment_1");
					put(grammarAccess.getConnectorInstanceReferenceClauseAccess().getTypeAssignment_0(), "rule__ConnectorInstanceReferenceClause__TypeAssignment_0");
					put(grammarAccess.getConnectorInstanceReferenceClauseAccess().getIdentifierAssignment_1(), "rule__ConnectorInstanceReferenceClause__IdentifierAssignment_1");
					put(grammarAccess.getObserveRelativeClauseAccess().getDirectionAssignment_0(), "rule__ObserveRelativeClause__DirectionAssignment_0");
					put(grammarAccess.getObserveRelativeClauseAccess().getTimeTargetAssignment_1(), "rule__ObserveRelativeClause__TimeTargetAssignment_1");
					put(grammarAccess.getObserveBetweenClauseAccess().getMode1Assignment_0(), "rule__ObserveBetweenClause__Mode1Assignment_0");
					put(grammarAccess.getObserveBetweenClauseAccess().getStartingTimeAssignment_1(), "rule__ObserveBetweenClause__StartingTimeAssignment_1");
					put(grammarAccess.getObserveBetweenClauseAccess().getMode2Assignment_2(), "rule__ObserveBetweenClause__Mode2Assignment_2");
					put(grammarAccess.getObserveBetweenClauseAccess().getEndingTimeAssignment_3(), "rule__ObserveBetweenClause__EndingTimeAssignment_3");
					put(grammarAccess.getRelativeTimeWithSignClauseAccess().getSignAssignment_0(), "rule__RelativeTimeWithSignClause__SignAssignment_0");
					put(grammarAccess.getRelativeTimeWithSignClauseAccess().getTimeClauseAssignment_1(), "rule__RelativeTimeWithSignClause__TimeClauseAssignment_1");
					put(grammarAccess.getAbsoluteTimeClauseAccess().getTimeSpecAssignment(), "rule__AbsoluteTimeClause__TimeSpecAssignment");
					put(grammarAccess.getRelativeTimeClauseAccess().getDurationClauseAssignment_0(), "rule__RelativeTimeClause__DurationClauseAssignment_0");
					put(grammarAccess.getRelativeTimeClauseAccess().getDurationClauseAssignment_1(), "rule__RelativeTimeClause__DurationClauseAssignment_1");
					put(grammarAccess.getRelativeTimeDurationClauseAccess().getDurationAssignment_0(), "rule__RelativeTimeDurationClause__DurationAssignment_0");
					put(grammarAccess.getRelativeTimeDurationClauseAccess().getTimeModifierAssignment_1(), "rule__RelativeTimeDurationClause__TimeModifierAssignment_1");
					put(grammarAccess.getWhatIfQueryAccess().getWhatIfVariationAssignment_1(), "rule__WhatIfQuery__WhatIfVariationAssignment_1");
					put(grammarAccess.getWhatIfQueryAccess().getMetricReferenceClausesAssignment_2_1(), "rule__WhatIfQuery__MetricReferenceClausesAssignment_2_1");
					put(grammarAccess.getWhatIfQueryAccess().getForClauseAssignment_2_2(), "rule__WhatIfQuery__ForClauseAssignment_2_2");
					put(grammarAccess.getWhatIfQueryAccess().getFilteringClauseAssignment_3(), "rule__WhatIfQuery__FilteringClauseAssignment_3");
					put(grammarAccess.getWhatIfQueryAccess().getDeltaClauseAssignment_4(), "rule__WhatIfQuery__DeltaClauseAssignment_4");
					put(grammarAccess.getWhatIfQueryAccess().getUsingClauseAssignment_5(), "rule__WhatIfQuery__UsingClauseAssignment_5");
					put(grammarAccess.getWhatIfVariationAccess().getWhatIfVariationClauseAssignment_0(), "rule__WhatIfVariation__WhatIfVariationClauseAssignment_0");
					put(grammarAccess.getWhatIfVariationAccess().getWhatIfVariationClauseAssignment_1_1(), "rule__WhatIfVariation__WhatIfVariationClauseAssignment_1_1");
					put(grammarAccess.getFilteringClauseAccess().getFilteringRuleAssignment_1_0(), "rule__FilteringClause__FilteringRuleAssignment_1_0");
					put(grammarAccess.getFilteringClauseAccess().getFilteringStrategyAssignment_1_1(), "rule__FilteringClause__FilteringStrategyAssignment_1_1");
					put(grammarAccess.getFilteringStrategyAccess().getFilteringStrategyAssignment(), "rule__FilteringStrategy__FilteringStrategyAssignment");
					put(grammarAccess.getFilteringRuleAccess().getFilteringValueAssignment_0(), "rule__FilteringRule__FilteringValueAssignment_0");
					put(grammarAccess.getFilteringRuleAccess().getModifierAssignment_1(), "rule__FilteringRule__ModifierAssignment_1");
					put(grammarAccess.getWhatIfVariationClauseAccess().getVariationPointAssignment_0(), "rule__WhatIfVariationClause__VariationPointAssignment_0");
					put(grammarAccess.getWhatIfVariationClauseAccess().getValuesAssignment_1(), "rule__WhatIfVariationClause__ValuesAssignment_1");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseAssignment_1(), "rule__WhatIfValueVariationClause__VariationClauseAssignment_1");
					put(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseAssignment_2_1(), "rule__WhatIfValueVariationClause__VariationClauseAssignment_2_1");
					put(grammarAccess.getMultipleVariationInstructionAccess().getMultiVariationAssignment_1(), "rule__MultipleVariationInstruction__MultiVariationAssignment_1");
					put(grammarAccess.getMultipleVariationInstructionAccess().getMultiVariationAssignment_2_1(), "rule__MultipleVariationInstruction__MultiVariationAssignment_2_1");
					put(grammarAccess.getVariationInstructionAccess().getVariationAssignment_0(), "rule__VariationInstruction__VariationAssignment_0");
					put(grammarAccess.getVariationInstructionAccess().getArgumentAssignment_1_1(), "rule__VariationInstruction__ArgumentAssignment_1_1");
					put(grammarAccess.getMultipleArithmeticClauseAccess().getMultiClauseAssignment_1(), "rule__MultipleArithmeticClause__MultiClauseAssignment_1");
					put(grammarAccess.getMultipleArithmeticClauseAccess().getMultiClauseAssignment_2_1(), "rule__MultipleArithmeticClause__MultiClauseAssignment_2_1");
					put(grammarAccess.getArithmeticClauseAccess().getModeAssignment_0(), "rule__ArithmeticClause__ModeAssignment_0");
					put(grammarAccess.getArithmeticClauseAccess().getValueAssignment_1(), "rule__ArithmeticClause__ValueAssignment_1");
					put(grammarAccess.getVariableValueAccess().getIntValueAssignment_0(), "rule__VariableValue__IntValueAssignment_0");
					put(grammarAccess.getVariableValueAccess().getDoubleValueAssignment_1(), "rule__VariableValue__DoubleValueAssignment_1");
				}
			};
		}
		return nameMappings.get(element);
	}
	
	@Override
	protected Collection<FollowElement> getFollowElements(AbstractInternalContentAssistParser parser) {
		try {
			tools.descartes.dql.lang.ui.contentassist.antlr.internal.InternalDescartesQLParser typedParser = (tools.descartes.dql.lang.ui.contentassist.antlr.internal.InternalDescartesQLParser) parser;
			typedParser.entryRuleDescartesQL();
			return typedParser.getFollowElements();
		} catch(RecognitionException ex) {
			throw new RuntimeException(ex);
		}		
	}
	
	@Override
	protected String[] getInitialHiddenTokens() {
		return new String[] { "RULE_WS", "RULE_ML_COMMENT", "RULE_SL_COMMENT" };
	}
	
	public DescartesQLGrammarAccess getGrammarAccess() {
		return this.grammarAccess;
	}
	
	public void setGrammarAccess(DescartesQLGrammarAccess grammarAccess) {
		this.grammarAccess = grammarAccess;
	}
}
