/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
grammar InternalDescartesQL;

options {
	superClass=AbstractInternalAntlrParser;
	
}

@lexer::header {
package tools.descartes.dql.lang.parser.antlr.internal;

// Hack: Use our own Lexer superclass by means of import. 
// Currently there is no other way to specify the superclass for the lexer.
import org.eclipse.xtext.parser.antlr.Lexer;
}

@parser::header {
package tools.descartes.dql.lang.parser.antlr.internal; 

import org.eclipse.xtext.*;
import org.eclipse.xtext.parser.*;
import org.eclipse.xtext.parser.impl.*;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.common.util.Enumerator;
import org.eclipse.xtext.parser.antlr.AbstractInternalAntlrParser;
import org.eclipse.xtext.parser.antlr.XtextTokenStream;
import org.eclipse.xtext.parser.antlr.XtextTokenStream.HiddenTokens;
import org.eclipse.xtext.parser.antlr.AntlrDatatypeRuleToken;
import tools.descartes.dql.lang.services.DescartesQLGrammarAccess;

}

@parser::members {

 	private DescartesQLGrammarAccess grammarAccess;
 	
    public InternalDescartesQLParser(TokenStream input, DescartesQLGrammarAccess grammarAccess) {
        this(input);
        this.grammarAccess = grammarAccess;
        registerRules(grammarAccess.getGrammar());
    }
    
    @Override
    protected String getFirstRuleName() {
    	return "DescartesQL";	
   	}
   	
   	@Override
   	protected DescartesQLGrammarAccess getGrammarAccess() {
   		return grammarAccess;
   	}
}

@rulecatch { 
    catch (RecognitionException re) { 
        recover(input,re); 
        appendSkippedTokens();
    } 
}




// Entry rule entryRuleDescartesQL
entryRuleDescartesQL returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDescartesQLRule()); }
	 iv_ruleDescartesQL=ruleDescartesQL 
	 { $current=$iv_ruleDescartesQL.current; } 
	 EOF 
;

// Rule DescartesQL
ruleDescartesQL returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
(
		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryModelStructureQueryParserRuleCall_0_0_0()); 
	    }
		lv_query_0_1=ruleModelStructureQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_1, 
        		"tools.descartes.dql.lang.DescartesQL.ModelStructureQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryPerformanceMetricsQueryParserRuleCall_0_0_1()); 
	    }
		lv_query_0_2=rulePerformanceMetricsQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_2, 
        		"tools.descartes.dql.lang.DescartesQL.PerformanceMetricsQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryPerformanceIssueQueryParserRuleCall_0_0_2()); 
	    }
		lv_query_0_3=rulePerformanceIssueQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_3, 
        		"tools.descartes.dql.lang.DescartesQL.PerformanceIssueQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryConnectorCapabilityQueryParserRuleCall_0_0_3()); 
	    }
		lv_query_0_4=ruleConnectorCapabilityQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_4, 
        		"tools.descartes.dql.lang.DescartesQL.ConnectorCapabilityQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryWhatIfQueryParserRuleCall_0_0_4()); 
	    }
		lv_query_0_5=ruleWhatIfQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_5, 
        		"tools.descartes.dql.lang.DescartesQL.WhatIfQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDescartesQLAccess().getQueryGoalParserRuleCall_0_0_5()); 
	    }
		lv_query_0_6=ruleGoal		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDescartesQLRule());
	        }
       		set(
       			$current, 
       			"query",
        		lv_query_0_6, 
        		"tools.descartes.dql.lang.DescartesQL.Goal");
	        afterParserOrEnumRuleCall();
	    }

)

)
)	otherlv_1=';' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getDescartesQLAccess().getSemicolonKeyword_1());
    }
)
;





// Entry rule entryRuleGoal
entryRuleGoal returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getGoalRule()); }
	 iv_ruleGoal=ruleGoal 
	 { $current=$iv_ruleGoal.current; } 
	 EOF 
;

// Rule Goal
ruleGoal returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
(
		lv_queryType_0_1=	'ENSURE' 
    {
        newLeafNode(lv_queryType_0_1, grammarAccess.getGoalAccess().getQueryTypeENSUREKeyword_0_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getGoalRule());
	        }
       		setWithLastConsumed($current, "queryType", lv_queryType_0_1, null);
	    }

    |		lv_queryType_0_2=	'MONITOR' 
    {
        newLeafNode(lv_queryType_0_2, grammarAccess.getGoalAccess().getQueryTypeMONITORKeyword_0_0_1());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getGoalRule());
	        }
       		setWithLastConsumed($current, "queryType", lv_queryType_0_2, null);
	    }

)

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getSlaQuerySlaQueryParserRuleCall_1_0()); 
	    }
		lv_slaQuery_1_0=ruleSlaQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"slaQuery",
        		lv_slaQuery_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.SlaQuery");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getSloQuerySloQueryParserRuleCall_2_0()); 
	    }
		lv_sloQuery_2_0=ruleSloQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"sloQuery",
        		lv_sloQuery_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.SloQuery");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getConstraintClauseConstraintClauseParserRuleCall_3_0()); 
	    }
		lv_constraintClause_3_0=ruleConstraintClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"constraintClause",
        		lv_constraintClause_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConstraintClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getDofClauseDoFClauseParserRuleCall_4_0()); 
	    }
		lv_dofClause_4_0=ruleDoFClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"dofClause",
        		lv_dofClause_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.DoFClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getForClauseForClauseParserRuleCall_5_0()); 
	    }
		lv_forClause_5_0=ruleForClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"forClause",
        		lv_forClause_5_0, 
        		"tools.descartes.dql.lang.DescartesQL.ForClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getGoalAccess().getUsingClauseUsingClauseParserRuleCall_6_0()); 
	    }
		lv_usingClause_6_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGoalRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_6_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleSlaQuery
entryRuleSlaQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSlaQueryRule()); }
	 iv_ruleSlaQuery=ruleSlaQuery 
	 { $current=$iv_ruleSlaQuery.current; } 
	 EOF 
;

// Rule SlaQuery
ruleSlaQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=	'AGREEMENTS' 
    {
        newLeafNode(lv_type_0_0, grammarAccess.getSlaQueryAccess().getTypeAGREEMENTSKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getSlaQueryRule());
	        }
       		setWithLastConsumed($current, "type", lv_type_0_0, "AGREEMENTS");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSlaQueryAccess().getSlasSlaParserRuleCall_1_0()); 
	    }
		lv_slas_1_0=ruleSla		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSlaQueryRule());
	        }
       		add(
       			$current, 
       			"slas",
        		lv_slas_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.Sla");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_2=',' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getSlaQueryAccess().getCommaKeyword_2_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSlaQueryAccess().getSlasSlaParserRuleCall_2_1_0()); 
	    }
		lv_slas_3_0=ruleSla		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSlaQueryRule());
	        }
       		add(
       			$current, 
       			"slas",
        		lv_slas_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.Sla");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleSloQuery
entryRuleSloQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSloQueryRule()); }
	 iv_ruleSloQuery=ruleSloQuery 
	 { $current=$iv_ruleSloQuery.current; } 
	 EOF 
;

// Rule SloQuery
ruleSloQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=	'GOALS' 
    {
        newLeafNode(lv_type_0_0, grammarAccess.getSloQueryAccess().getTypeGOALSKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getSloQueryRule());
	        }
       		setWithLastConsumed($current, "type", lv_type_0_0, "GOALS");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSloQueryAccess().getSlosSloParserRuleCall_1_0()); 
	    }
		lv_slos_1_0=ruleSlo		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloQueryRule());
	        }
       		add(
       			$current, 
       			"slos",
        		lv_slos_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.Slo");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_2=',' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getSloQueryAccess().getCommaKeyword_2_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSloQueryAccess().getSlosSloParserRuleCall_2_1_0()); 
	    }
		lv_slos_3_0=ruleSlo		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloQueryRule());
	        }
       		add(
       			$current, 
       			"slos",
        		lv_slos_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.Slo");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleSla
entryRuleSla returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSlaRule()); }
	 iv_ruleSla=ruleSla 
	 { $current=$iv_ruleSla.current; } 
	 EOF 
;

// Rule Sla
ruleSla returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_name_0_0=RULE_ID
		{
			newLeafNode(lv_name_0_0, grammarAccess.getSlaAccess().getNameIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getSlaRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"name",
        		lv_name_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)	otherlv_1='CONTAINS' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getSlaAccess().getCONTAINSKeyword_1());
    }
	otherlv_2='(' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getSlaAccess().getLeftParenthesisKeyword_2());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSlaAccess().getWeightedSloWeightedSloParserRuleCall_3_0()); 
	    }
		lv_weightedSlo_3_0=ruleWeightedSlo		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSlaRule());
	        }
       		add(
       			$current, 
       			"weightedSlo",
        		lv_weightedSlo_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.WeightedSlo");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_4=',' 
    {
    	newLeafNode(otherlv_4, grammarAccess.getSlaAccess().getCommaKeyword_4_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSlaAccess().getWeightedSloWeightedSloParserRuleCall_4_1_0()); 
	    }
		lv_weightedSlo_5_0=ruleWeightedSlo		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSlaRule());
	        }
       		add(
       			$current, 
       			"weightedSlo",
        		lv_weightedSlo_5_0, 
        		"tools.descartes.dql.lang.DescartesQL.WeightedSlo");
	        afterParserOrEnumRuleCall();
	    }

)
))*	otherlv_6=')' 
    {
    	newLeafNode(otherlv_6, grammarAccess.getSlaAccess().getRightParenthesisKeyword_5());
    }
)
;





// Entry rule entryRuleSlo
entryRuleSlo returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSloRule()); }
	 iv_ruleSlo=ruleSlo 
	 { $current=$iv_ruleSlo.current; } 
	 EOF 
;

// Rule Slo
ruleSlo returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_name_0_0=RULE_ID
		{
			newLeafNode(lv_name_0_0, grammarAccess.getSloAccess().getNameIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getSloRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"name",
        		lv_name_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)	otherlv_1=':' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getSloAccess().getColonKeyword_1());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSloAccess().getMetricClauseTypeMetricClauseTypeParserRuleCall_2_0()); 
	    }
		lv_metricClauseType_2_0=ruleMetricClauseType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloRule());
	        }
       		set(
       			$current, 
       			"metricClauseType",
        		lv_metricClauseType_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClauseType");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSloAccess().getComparatorComparatorEnumRuleCall_3_0()); 
	    }
		lv_comparator_3_0=ruleComparator		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloRule());
	        }
       		set(
       			$current, 
       			"comparator",
        		lv_comparator_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.Comparator");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSloAccess().getValueVariableValueParserRuleCall_4_0()); 
	    }
		lv_value_4_0=ruleVariableValue		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloRule());
	        }
       		set(
       			$current, 
       			"value",
        		lv_value_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.VariableValue");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSloAccess().getFuzFuzzinessParserRuleCall_5_0()); 
	    }
		lv_fuz_5_0=ruleFuzziness		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloRule());
	        }
       		set(
       			$current, 
       			"fuz",
        		lv_fuz_5_0, 
        		"tools.descartes.dql.lang.DescartesQL.Fuzziness");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getSloAccess().getPenPenaltyParserRuleCall_6_0()); 
	    }
		lv_pen_6_0=rulePenalty		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSloRule());
	        }
       		set(
       			$current, 
       			"pen",
        		lv_pen_6_0, 
        		"tools.descartes.dql.lang.DescartesQL.Penalty");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleWeightedSlo
entryRuleWeightedSlo returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWeightedSloRule()); }
	 iv_ruleWeightedSlo=ruleWeightedSlo 
	 { $current=$iv_ruleWeightedSlo.current; } 
	 EOF 
;

// Rule WeightedSlo
ruleWeightedSlo returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{
			if ($current==null) {
	            $current = createModelElement(grammarAccess.getWeightedSloRule());
	        }
        }
	otherlv_0=RULE_ID
	{
		newLeafNode(otherlv_0, grammarAccess.getWeightedSloAccess().getSloSloCrossReference_0_0()); 
	}

)
)(	otherlv_1='*' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getWeightedSloAccess().getAsteriskKeyword_1_0());
    }
(
(
		lv_weight_2_0=RULE_INT
		{
			newLeafNode(lv_weight_2_0, grammarAccess.getWeightedSloAccess().getWeightINTTerminalRuleCall_1_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getWeightedSloRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"weight",
        		lv_weight_2_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
))?)
;





// Entry rule entryRuleFuzziness
entryRuleFuzziness returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFuzzinessRule()); }
	 iv_ruleFuzziness=ruleFuzziness 
	 { $current=$iv_ruleFuzziness.current; } 
	 EOF 
;

// Rule Fuzziness
ruleFuzziness returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=	'FUZZINESS' 
    {
        newLeafNode(lv_type_0_0, grammarAccess.getFuzzinessAccess().getTypeFUZZINESSKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFuzzinessRule());
	        }
       		setWithLastConsumed($current, "type", lv_type_0_0, "FUZZINESS");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getFuzzinessAccess().getDeviationVariableValueParserRuleCall_1_0()); 
	    }
		lv_deviation_1_0=ruleVariableValue		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFuzzinessRule());
	        }
       		set(
       			$current, 
       			"deviation",
        		lv_deviation_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.VariableValue");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRulePenalty
entryRulePenalty returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getPenaltyRule()); }
	 iv_rulePenalty=rulePenalty 
	 { $current=$iv_rulePenalty.current; } 
	 EOF 
;

// Rule Penalty
rulePenalty returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=	'PENALTY' 
    {
        newLeafNode(lv_type_0_0, grammarAccess.getPenaltyAccess().getTypePENALTYKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getPenaltyRule());
	        }
       		setWithLastConsumed($current, "type", lv_type_0_0, "PENALTY");
	    }

)
)(
(
		lv_value_1_0=RULE_DOUBLE
		{
			newLeafNode(lv_value_1_0, grammarAccess.getPenaltyAccess().getValueDOUBLETerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getPenaltyRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.DOUBLE");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getPenaltyAccess().getCurrencyCurrencyEnumRuleCall_2_0()); 
	    }
		lv_currency_2_0=ruleCurrency		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getPenaltyRule());
	        }
       		set(
       			$current, 
       			"currency",
        		lv_currency_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.Currency");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getPenaltyAccess().getViolationViolationParserRuleCall_3_0()); 
	    }
		lv_violation_3_0=ruleViolation		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getPenaltyRule());
	        }
       		set(
       			$current, 
       			"violation",
        		lv_violation_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.Violation");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleViolation
entryRuleViolation returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getViolationRule()); }
	 iv_ruleViolation=ruleViolation 
	 { $current=$iv_ruleViolation.current; } 
	 EOF 
;

// Rule Violation
ruleViolation returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='PER' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getViolationAccess().getPERKeyword_0());
    }
(
(
		lv_amount_1_0=RULE_INT
		{
			newLeafNode(lv_amount_1_0, grammarAccess.getViolationAccess().getAmountINTTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getViolationRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"amount",
        		lv_amount_1_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)	otherlv_2='VIOLATIONS' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getViolationAccess().getVIOLATIONSKeyword_2());
    }
)
;





// Entry rule entryRuleModelStructureQuery
entryRuleModelStructureQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getModelStructureQueryRule()); }
	 iv_ruleModelStructureQuery=ruleModelStructureQuery 
	 { $current=$iv_ruleModelStructureQuery.current; } 
	 EOF 
;

// Rule ModelStructureQuery
ruleModelStructureQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:

    { 
        newCompositeNode(grammarAccess.getModelStructureQueryAccess().getListQueryParserRuleCall()); 
    }
    this_ListQuery_0=ruleListQuery
    { 
        $current = $this_ListQuery_0.current; 
        afterParserOrEnumRuleCall();
    }

;





// Entry rule entryRulePerformanceMetricsQuery
entryRulePerformanceMetricsQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getPerformanceMetricsQueryRule()); }
	 iv_rulePerformanceMetricsQuery=rulePerformanceMetricsQuery 
	 { $current=$iv_rulePerformanceMetricsQuery.current; } 
	 EOF 
;

// Rule PerformanceMetricsQuery
rulePerformanceMetricsQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:

    { 
        newCompositeNode(grammarAccess.getPerformanceMetricsQueryAccess().getSelectQueryParserRuleCall()); 
    }
    this_SelectQuery_0=ruleSelectQuery
    { 
        $current = $this_SelectQuery_0.current; 
        afterParserOrEnumRuleCall();
    }

;





// Entry rule entryRulePerformanceIssueQuery
entryRulePerformanceIssueQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getPerformanceIssueQueryRule()); }
	 iv_rulePerformanceIssueQuery=rulePerformanceIssueQuery 
	 { $current=$iv_rulePerformanceIssueQuery.current; } 
	 EOF 
;

// Rule PerformanceIssueQuery
rulePerformanceIssueQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:

    { 
        newCompositeNode(grammarAccess.getPerformanceIssueQueryAccess().getDetectQueryParserRuleCall()); 
    }
    this_DetectQuery_0=ruleDetectQuery
    { 
        $current = $this_DetectQuery_0.current; 
        afterParserOrEnumRuleCall();
    }

;





// Entry rule entryRuleConnectorCapabilityQuery
entryRuleConnectorCapabilityQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConnectorCapabilityQueryRule()); }
	 iv_ruleConnectorCapabilityQuery=ruleConnectorCapabilityQuery 
	 { $current=$iv_ruleConnectorCapabilityQuery.current; } 
	 EOF 
;

// Rule ConnectorCapabilityQuery
ruleConnectorCapabilityQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:

    { 
        newCompositeNode(grammarAccess.getConnectorCapabilityQueryAccess().getGetQueryParserRuleCall()); 
    }
    this_GetQuery_0=ruleGetQuery
    { 
        $current = $this_GetQuery_0.current; 
        afterParserOrEnumRuleCall();
    }

;





// Entry rule entryRuleListQuery
entryRuleListQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getListQueryRule()); }
	 iv_ruleListQuery=ruleListQuery 
	 { $current=$iv_ruleListQuery.current; } 
	 EOF 
;

// Rule ListQuery
ruleListQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='LIST' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getListQueryAccess().getLISTKeyword_0());
    }
(
(
(
		{ 
	        newCompositeNode(grammarAccess.getListQueryAccess().getQueryTypeListEntitiesQueryParserRuleCall_1_0_0()); 
	    }
		lv_queryType_1_1=ruleListEntitiesQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListQueryRule());
	        }
       		set(
       			$current, 
       			"queryType",
        		lv_queryType_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.ListEntitiesQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getListQueryAccess().getQueryTypeListMetricsQueryParserRuleCall_1_0_1()); 
	    }
		lv_queryType_1_2=ruleListMetricsQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListQueryRule());
	        }
       		set(
       			$current, 
       			"queryType",
        		lv_queryType_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.ListMetricsQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getListQueryAccess().getQueryTypeListDoFQueryParserRuleCall_1_0_2()); 
	    }
		lv_queryType_1_3=ruleListDoFQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListQueryRule());
	        }
       		set(
       			$current, 
       			"queryType",
        		lv_queryType_1_3, 
        		"tools.descartes.dql.lang.DescartesQL.ListDoFQuery");
	        afterParserOrEnumRuleCall();
	    }

)

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getListQueryAccess().getFilterClauseFilterClauseParserRuleCall_2_0()); 
	    }
		lv_filterClause_2_0=ruleFilterClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListQueryRule());
	        }
       		set(
       			$current, 
       			"filterClause",
        		lv_filterClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getListQueryAccess().getUsingClauseUsingClauseParserRuleCall_3_0()); 
	    }
		lv_usingClause_3_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListQueryRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleGetQuery
entryRuleGetQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getGetQueryRule()); }
	 iv_ruleGetQuery=ruleGetQuery 
	 { $current=$iv_ruleGetQuery.current; } 
	 EOF 
;

// Rule GetQuery
ruleGetQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='GET' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getGetQueryAccess().getGETKeyword_0());
    }
(
(
(
		{ 
	        newCompositeNode(grammarAccess.getGetQueryAccess().getQueryTapeGetExplorationStrategiesQueryParserRuleCall_1_0_0()); 
	    }
		lv_queryTape_1_1=ruleGetExplorationStrategiesQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGetQueryRule());
	        }
       		set(
       			$current, 
       			"queryTape",
        		lv_queryTape_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.GetExplorationStrategiesQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getGetQueryAccess().getQueryTapeGetTimeUnitsQueryParserRuleCall_1_0_1()); 
	    }
		lv_queryTape_1_2=ruleGetTimeUnitsQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGetQueryRule());
	        }
       		set(
       			$current, 
       			"queryTape",
        		lv_queryTape_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.GetTimeUnitsQuery");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getGetQueryAccess().getQueryTapeGetConstraintsQueryParserRuleCall_1_0_2()); 
	    }
		lv_queryTape_1_3=ruleGetConstraintsQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGetQueryRule());
	        }
       		set(
       			$current, 
       			"queryTape",
        		lv_queryTape_1_3, 
        		"tools.descartes.dql.lang.DescartesQL.GetConstraintsQuery");
	        afterParserOrEnumRuleCall();
	    }

)

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getGetQueryAccess().getUsingClauseUsingClauseParserRuleCall_2_0()); 
	    }
		lv_usingClause_2_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getGetQueryRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleGetConstraintsQuery
entryRuleGetConstraintsQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getGetConstraintsQueryRule()); }
	 iv_ruleGetConstraintsQuery=ruleGetConstraintsQuery 
	 { $current=$iv_ruleGetConstraintsQuery.current; } 
	 EOF 
;

// Rule GetConstraintsQuery
ruleGetConstraintsQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_mode_0_0=	'CONSTRAINTS' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getGetConstraintsQueryAccess().getModeCONSTRAINTSKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getGetConstraintsQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "CONSTRAINTS");
	    }

)
)
;





// Entry rule entryRuleGetExplorationStrategiesQuery
entryRuleGetExplorationStrategiesQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getGetExplorationStrategiesQueryRule()); }
	 iv_ruleGetExplorationStrategiesQuery=ruleGetExplorationStrategiesQuery 
	 { $current=$iv_ruleGetExplorationStrategiesQuery.current; } 
	 EOF 
;

// Rule GetExplorationStrategiesQuery
ruleGetExplorationStrategiesQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_mode_0_0=	'EXPLORATION STRATEGIES' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getGetExplorationStrategiesQueryAccess().getModeEXPLORATIONSTRATEGIESKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getGetExplorationStrategiesQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "EXPLORATION STRATEGIES");
	    }

)
)
;





// Entry rule entryRuleGetTimeUnitsQuery
entryRuleGetTimeUnitsQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getGetTimeUnitsQueryRule()); }
	 iv_ruleGetTimeUnitsQuery=ruleGetTimeUnitsQuery 
	 { $current=$iv_ruleGetTimeUnitsQuery.current; } 
	 EOF 
;

// Rule GetTimeUnitsQuery
ruleGetTimeUnitsQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_mode_0_0=	'TIME UNITS' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getGetTimeUnitsQueryAccess().getModeTIMEUNITSKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getGetTimeUnitsQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "TIME UNITS");
	    }

)
)
;





// Entry rule entryRuleListDoFQuery
entryRuleListDoFQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getListDoFQueryRule()); }
	 iv_ruleListDoFQuery=ruleListDoFQuery 
	 { $current=$iv_ruleListDoFQuery.current; } 
	 EOF 
;

// Rule ListDoFQuery
ruleListDoFQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'DOF' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getListDoFQueryAccess().getModeDOFKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getListDoFQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "DOF");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getListDoFQueryAccess().getWithClauseWithClauseParserRuleCall_1_0()); 
	    }
		lv_withClause_1_0=ruleWithClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListDoFQueryRule());
	        }
       		set(
       			$current, 
       			"withClause",
        		lv_withClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.WithClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleListEntitiesQuery
entryRuleListEntitiesQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getListEntitiesQueryRule()); }
	 iv_ruleListEntitiesQuery=ruleListEntitiesQuery 
	 { $current=$iv_ruleListEntitiesQuery.current; } 
	 EOF 
;

// Rule ListEntitiesQuery
ruleListEntitiesQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_mode_0_0=	'ENTITIES' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getListEntitiesQueryAccess().getModeENTITIESKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getListEntitiesQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "ENTITIES");
	    }

)
)
;





// Entry rule entryRuleListMetricsQuery
entryRuleListMetricsQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getListMetricsQueryRule()); }
	 iv_ruleListMetricsQuery=ruleListMetricsQuery 
	 { $current=$iv_ruleListMetricsQuery.current; } 
	 EOF 
;

// Rule ListMetricsQuery
ruleListMetricsQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'METRICS' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getListMetricsQueryAccess().getModeMETRICSKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getListMetricsQueryRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "METRICS");
	    }

)
)	otherlv_1='(' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getListMetricsQueryAccess().getLeftParenthesisKeyword_1());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getListMetricsQueryAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0()); 
	    }
		lv_entityReferenceClause_2_0=ruleEntityReferenceClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getListMetricsQueryRule());
	        }
       		set(
       			$current, 
       			"entityReferenceClause",
        		lv_entityReferenceClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.EntityReferenceClause");
	        afterParserOrEnumRuleCall();
	    }

)
)	otherlv_3=')' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getListMetricsQueryAccess().getRightParenthesisKeyword_3());
    }
)
;





// Entry rule entryRuleSelectQuery
entryRuleSelectQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSelectQueryRule()); }
	 iv_ruleSelectQuery=ruleSelectQuery 
	 { $current=$iv_ruleSelectQuery.current; } 
	 EOF 
;

// Rule SelectQuery
ruleSelectQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='SELECT' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getSelectQueryAccess().getSELECTKeyword_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getMetricReferenceClausesMetricReferenceClausesParserRuleCall_1_0()); 
	    }
		lv_metricReferenceClauses_1_0=ruleMetricReferenceClauses		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"metricReferenceClauses",
        		lv_metricReferenceClauses_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricReferenceClauses");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getConstraintClauseConstraintClauseParserRuleCall_2_0()); 
	    }
		lv_constraintClause_2_0=ruleConstraintClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"constraintClause",
        		lv_constraintClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConstraintClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getDofClauseDoFClauseParserRuleCall_3_0()); 
	    }
		lv_dofClause_3_0=ruleDoFClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"dofClause",
        		lv_dofClause_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.DoFClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getForClauseForClauseParserRuleCall_4_0()); 
	    }
		lv_forClause_4_0=ruleForClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"forClause",
        		lv_forClause_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.ForClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getUsingClauseUsingClauseParserRuleCall_5_0()); 
	    }
		lv_usingClause_5_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_5_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSelectQueryAccess().getObserveClauseObserveClauseParserRuleCall_6_0()); 
	    }
		lv_observeClause_6_0=ruleObserveClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSelectQueryRule());
	        }
       		set(
       			$current, 
       			"observeClause",
        		lv_observeClause_6_0, 
        		"tools.descartes.dql.lang.DescartesQL.ObserveClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleMetricReferenceClauses
entryRuleMetricReferenceClauses returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricReferenceClausesRule()); }
	 iv_ruleMetricReferenceClauses=ruleMetricReferenceClauses 
	 { $current=$iv_ruleMetricReferenceClauses.current; } 
	 EOF 
;

// Rule MetricReferenceClauses
ruleMetricReferenceClauses returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getMetricReferenceClausesAccess().getMetricClauseTypesMetricClauseTypeParserRuleCall_0_0()); 
	    }
		lv_metricClauseTypes_0_0=ruleMetricClauseType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricReferenceClausesRule());
	        }
       		add(
       			$current, 
       			"metricClauseTypes",
        		lv_metricClauseTypes_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClauseType");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getMetricReferenceClausesAccess().getCommaKeyword_1_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getMetricReferenceClausesAccess().getMetricClauseTypesMetricClauseTypeParserRuleCall_1_1_0()); 
	    }
		lv_metricClauseTypes_2_0=ruleMetricClauseType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricReferenceClausesRule());
	        }
       		add(
       			$current, 
       			"metricClauseTypes",
        		lv_metricClauseTypes_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClauseType");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleMetricClauseType
entryRuleMetricClauseType returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricClauseTypeRule()); }
	 iv_ruleMetricClauseType=ruleMetricClauseType 
	 { $current=$iv_ruleMetricClauseType.current; } 
	 EOF 
;

// Rule MetricClauseType
ruleMetricClauseType returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
    { 
        newCompositeNode(grammarAccess.getMetricClauseTypeAccess().getMetricClauseParserRuleCall_0()); 
    }
    this_MetricClause_0=ruleMetricClause
    { 
        $current = $this_MetricClause_0.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getMetricClauseTypeAccess().getAggregateMetricClauseParserRuleCall_1()); 
    }
    this_AggregateMetricClause_1=ruleAggregateMetricClause
    { 
        $current = $this_AggregateMetricClause_1.current; 
        afterParserOrEnumRuleCall();
    }
)
;





// Entry rule entryRuleDetectQuery
entryRuleDetectQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDetectQueryRule()); }
	 iv_ruleDetectQuery=ruleDetectQuery 
	 { $current=$iv_ruleDetectQuery.current; } 
	 EOF 
;

// Rule DetectQuery
ruleDetectQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='DETECT' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getDetectQueryAccess().getDETECTKeyword_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getDetectQueryAccess().getQueryTypeDetectBottlenecksQueryParserRuleCall_1_0()); 
	    }
		lv_queryType_1_0=ruleDetectBottlenecksQuery		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDetectQueryRule());
	        }
       		set(
       			$current, 
       			"queryType",
        		lv_queryType_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.DetectBottlenecksQuery");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleDetectBottlenecksQuery
entryRuleDetectBottlenecksQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDetectBottlenecksQueryRule()); }
	 iv_ruleDetectBottlenecksQuery=ruleDetectBottlenecksQuery 
	 { $current=$iv_ruleDetectBottlenecksQuery.current; } 
	 EOF 
;

// Rule DetectBottlenecksQuery
ruleDetectBottlenecksQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='BOTTLENECKS' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getDetectBottlenecksQueryAccess().getBOTTLENECKSKeyword_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getDetectBottlenecksQueryAccess().getDofClauseDoFClauseParserRuleCall_1_0()); 
	    }
		lv_dofClause_1_0=ruleDoFClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDetectBottlenecksQueryRule());
	        }
       		set(
       			$current, 
       			"dofClause",
        		lv_dofClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.DoFClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getDetectBottlenecksQueryAccess().getUsingClauseUsingClauseParserRuleCall_2_0()); 
	    }
		lv_usingClause_2_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDetectBottlenecksQueryRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleConstraintClause
entryRuleConstraintClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConstraintClauseRule()); }
	 iv_ruleConstraintClause=ruleConstraintClause 
	 { $current=$iv_ruleConstraintClause.current; } 
	 EOF 
;

// Rule ConstraintClause
ruleConstraintClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='CONSTRAINED AS' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getConstraintClauseAccess().getCONSTRAINEDASKeyword_0());
    }
(
(
		lv_type_1_0=RULE_STRING
		{
			newLeafNode(lv_type_1_0, grammarAccess.getConstraintClauseAccess().getTypeSTRINGTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConstraintClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"type",
        		lv_type_1_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
))
;





// Entry rule entryRuleDoFClause
entryRuleDoFClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDoFClauseRule()); }
	 iv_ruleDoFClause=ruleDoFClause 
	 { $current=$iv_ruleDoFClause.current; } 
	 EOF 
;

// Rule DoFClause
ruleDoFClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'EVALUATE DOF' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getDoFClauseAccess().getModeEVALUATEDOFKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoFClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "EVALUATE DOF");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFClauseAccess().getVaryingClauseVaryingClauseParserRuleCall_1_0()); 
	    }
		lv_varyingClause_1_0=ruleVaryingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFClauseRule());
	        }
       		set(
       			$current, 
       			"varyingClause",
        		lv_varyingClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.VaryingClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFClauseAccess().getExplorationStrategyExplorationStrategyClauseParserRuleCall_2_0()); 
	    }
		lv_explorationStrategy_2_0=ruleExplorationStrategyClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFClauseRule());
	        }
       		set(
       			$current, 
       			"explorationStrategy",
        		lv_explorationStrategy_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.ExplorationStrategyClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFClauseAccess().getConstraintClauseConstraintClauseParserRuleCall_3_0()); 
	    }
		lv_constraintClause_3_0=ruleConstraintClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFClauseRule());
	        }
       		set(
       			$current, 
       			"constraintClause",
        		lv_constraintClause_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConstraintClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFClauseAccess().getWithClauseWithClauseParserRuleCall_4_0()); 
	    }
		lv_withClause_4_0=ruleWithClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFClauseRule());
	        }
       		set(
       			$current, 
       			"withClause",
        		lv_withClause_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.WithClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleExplorationStrategyClause
entryRuleExplorationStrategyClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getExplorationStrategyClauseRule()); }
	 iv_ruleExplorationStrategyClause=ruleExplorationStrategyClause 
	 { $current=$iv_ruleExplorationStrategyClause.current; } 
	 EOF 
;

// Rule ExplorationStrategyClause
ruleExplorationStrategyClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'GUIDED BY' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getExplorationStrategyClauseAccess().getModeGUIDEDBYKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getExplorationStrategyClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "GUIDED BY");
	    }

)
)(
(
		lv_name_1_0=RULE_STRING
		{
			newLeafNode(lv_name_1_0, grammarAccess.getExplorationStrategyClauseAccess().getNameSTRINGTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getExplorationStrategyClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"name",
        		lv_name_1_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getExplorationStrategyClauseAccess().getParameterClauseConfigurationPropertiesClauseParserRuleCall_2_0()); 
	    }
		lv_parameterClause_2_0=ruleConfigurationPropertiesClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getExplorationStrategyClauseRule());
	        }
       		set(
       			$current, 
       			"parameterClause",
        		lv_parameterClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConfigurationPropertiesClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleConfigurationPropertiesClause
entryRuleConfigurationPropertiesClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConfigurationPropertiesClauseRule()); }
	 iv_ruleConfigurationPropertiesClause=ruleConfigurationPropertiesClause 
	 { $current=$iv_ruleConfigurationPropertiesClause.current; } 
	 EOF 
;

// Rule ConfigurationPropertiesClause
ruleConfigurationPropertiesClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode1_0_0=	'[' 
    {
        newLeafNode(lv_mode1_0_0, grammarAccess.getConfigurationPropertiesClauseAccess().getMode1LeftSquareBracketKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConfigurationPropertiesClauseRule());
	        }
       		setWithLastConsumed($current, "mode1", lv_mode1_0_0, "[");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getConfigurationPropertiesClauseAccess().getPropertiesConfigurationPropertyClauseParserRuleCall_1_0()); 
	    }
		lv_properties_1_0=ruleConfigurationPropertyClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getConfigurationPropertiesClauseRule());
	        }
       		add(
       			$current, 
       			"properties",
        		lv_properties_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConfigurationPropertyClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_2=',' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getConfigurationPropertiesClauseAccess().getCommaKeyword_2_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getConfigurationPropertiesClauseAccess().getPropertiesConfigurationPropertyClauseParserRuleCall_2_1_0()); 
	    }
		lv_properties_3_0=ruleConfigurationPropertyClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getConfigurationPropertiesClauseRule());
	        }
       		add(
       			$current, 
       			"properties",
        		lv_properties_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConfigurationPropertyClause");
	        afterParserOrEnumRuleCall();
	    }

)
))*(
(
		lv_mode2_4_0=	']' 
    {
        newLeafNode(lv_mode2_4_0, grammarAccess.getConfigurationPropertiesClauseAccess().getMode2RightSquareBracketKeyword_3_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConfigurationPropertiesClauseRule());
	        }
       		setWithLastConsumed($current, "mode2", lv_mode2_4_0, "]");
	    }

)
))
;





// Entry rule entryRuleConfigurationPropertyClause
entryRuleConfigurationPropertyClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConfigurationPropertyClauseRule()); }
	 iv_ruleConfigurationPropertyClause=ruleConfigurationPropertyClause 
	 { $current=$iv_ruleConfigurationPropertyClause.current; } 
	 EOF 
;

// Rule ConfigurationPropertyClause
ruleConfigurationPropertyClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_key_0_0=RULE_ID
		{
			newLeafNode(lv_key_0_0, grammarAccess.getConfigurationPropertyClauseAccess().getKeyIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConfigurationPropertyClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"key",
        		lv_key_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)(	otherlv_1='.' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getConfigurationPropertyClauseAccess().getFullStopKeyword_1_0());
    }
(
(
		lv_key_2_0=RULE_ID
		{
			newLeafNode(lv_key_2_0, grammarAccess.getConfigurationPropertyClauseAccess().getKeyIDTerminalRuleCall_1_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConfigurationPropertyClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"key",
        		lv_key_2_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
))*	otherlv_3='=' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getConfigurationPropertyClauseAccess().getEqualsSignKeyword_2());
    }
(
(
		lv_value_4_0=RULE_STRING
		{
			newLeafNode(lv_value_4_0, grammarAccess.getConfigurationPropertyClauseAccess().getValueSTRINGTerminalRuleCall_3_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConfigurationPropertyClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_4_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
))
;





// Entry rule entryRuleDoFVariationClause
entryRuleDoFVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDoFVariationClauseRule()); }
	 iv_ruleDoFVariationClause=ruleDoFVariationClause 
	 { $current=$iv_ruleDoFVariationClause.current; } 
	 EOF 
;

// Rule DoFVariationClause
ruleDoFVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode1_0_0=	'<' 
    {
        newLeafNode(lv_mode1_0_0, grammarAccess.getDoFVariationClauseAccess().getMode1LessThanSignKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoFVariationClauseRule());
	        }
       		setWithLastConsumed($current, "mode1", lv_mode1_0_0, "<");
	    }

)
)(
(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFVariationClauseAccess().getVariationIntervalVariationClauseParserRuleCall_1_0_0()); 
	    }
		lv_variation_1_1=ruleIntervalVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFVariationClauseRule());
	        }
       		set(
       			$current, 
       			"variation",
        		lv_variation_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.IntervalVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDoFVariationClauseAccess().getVariationValueVariationClauseParserRuleCall_1_0_1()); 
	    }
		lv_variation_1_2=ruleValueVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFVariationClauseRule());
	        }
       		set(
       			$current, 
       			"variation",
        		lv_variation_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.ValueVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDoFVariationClauseAccess().getVariationDoubleValueVariationClauseParserRuleCall_1_0_2()); 
	    }
		lv_variation_1_3=ruleDoubleValueVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFVariationClauseRule());
	        }
       		set(
       			$current, 
       			"variation",
        		lv_variation_1_3, 
        		"tools.descartes.dql.lang.DescartesQL.DoubleValueVariationClause");
	        afterParserOrEnumRuleCall();
	    }

)

)
)(
(
		lv_mode2_2_0=	'>' 
    {
        newLeafNode(lv_mode2_2_0, grammarAccess.getDoFVariationClauseAccess().getMode2GreaterThanSignKeyword_2_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoFVariationClauseRule());
	        }
       		setWithLastConsumed($current, "mode2", lv_mode2_2_0, ">");
	    }

)
))
;





// Entry rule entryRuleValueVariationClause
entryRuleValueVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getValueVariationClauseRule()); }
	 iv_ruleValueVariationClause=ruleValueVariationClause 
	 { $current=$iv_ruleValueVariationClause.current; } 
	 EOF 
;

// Rule ValueVariationClause
ruleValueVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_value_0_0=RULE_INT
		{
			newLeafNode(lv_value_0_0, grammarAccess.getValueVariationClauseAccess().getValueINTTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getValueVariationClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_0_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getValueVariationClauseAccess().getCommaKeyword_1_0());
    }
(
(
		lv_value_2_0=RULE_INT
		{
			newLeafNode(lv_value_2_0, grammarAccess.getValueVariationClauseAccess().getValueINTTerminalRuleCall_1_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getValueVariationClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_2_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
))*)
;





// Entry rule entryRuleDoubleValueVariationClause
entryRuleDoubleValueVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDoubleValueVariationClauseRule()); }
	 iv_ruleDoubleValueVariationClause=ruleDoubleValueVariationClause 
	 { $current=$iv_ruleDoubleValueVariationClause.current; } 
	 EOF 
;

// Rule DoubleValueVariationClause
ruleDoubleValueVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_value_0_0=RULE_DOUBLE
		{
			newLeafNode(lv_value_0_0, grammarAccess.getDoubleValueVariationClauseAccess().getValueDOUBLETerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoubleValueVariationClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.DOUBLE");
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getDoubleValueVariationClauseAccess().getCommaKeyword_1_0());
    }
(
(
		lv_value_2_0=RULE_DOUBLE
		{
			newLeafNode(lv_value_2_0, grammarAccess.getDoubleValueVariationClauseAccess().getValueDOUBLETerminalRuleCall_1_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoubleValueVariationClauseRule());
	        }
       		addWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.DOUBLE");
	    }

)
))*)
;





// Entry rule entryRuleIntervalVariationClause
entryRuleIntervalVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getIntervalVariationClauseRule()); }
	 iv_ruleIntervalVariationClause=ruleIntervalVariationClause 
	 { $current=$iv_ruleIntervalVariationClause.current; } 
	 EOF 
;

// Rule IntervalVariationClause
ruleIntervalVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_start_0_0=RULE_INT
		{
			newLeafNode(lv_start_0_0, grammarAccess.getIntervalVariationClauseAccess().getStartINTTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getIntervalVariationClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"start",
        		lv_start_0_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)	otherlv_1='..' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getIntervalVariationClauseAccess().getFullStopFullStopKeyword_1());
    }
(
(
		lv_end_2_0=RULE_INT
		{
			newLeafNode(lv_end_2_0, grammarAccess.getIntervalVariationClauseAccess().getEndINTTerminalRuleCall_2_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getIntervalVariationClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"end",
        		lv_end_2_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)	otherlv_3='BY' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getIntervalVariationClauseAccess().getBYKeyword_3());
    }
(
(
		lv_step_4_0=RULE_INT
		{
			newLeafNode(lv_step_4_0, grammarAccess.getIntervalVariationClauseAccess().getStepINTTerminalRuleCall_4_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getIntervalVariationClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"step",
        		lv_step_4_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
))
;





// Entry rule entryRuleVaryingClause
entryRuleVaryingClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getVaryingClauseRule()); }
	 iv_ruleVaryingClause=ruleVaryingClause 
	 { $current=$iv_ruleVaryingClause.current; } 
	 EOF 
;

// Rule VaryingClause
ruleVaryingClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'VARYING' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getVaryingClauseAccess().getModeVARYINGKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getVaryingClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "VARYING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getVaryingClauseAccess().getDofReferencesDoFReferenceParserRuleCall_1_0()); 
	    }
		lv_dofReferences_1_0=ruleDoFReference		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getVaryingClauseRule());
	        }
       		add(
       			$current, 
       			"dofReferences",
        		lv_dofReferences_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.DoFReference");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_2=',' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getVaryingClauseAccess().getCommaKeyword_2_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getVaryingClauseAccess().getDofReferencesDoFReferenceParserRuleCall_2_1_0()); 
	    }
		lv_dofReferences_3_0=ruleDoFReference		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getVaryingClauseRule());
	        }
       		add(
       			$current, 
       			"dofReferences",
        		lv_dofReferences_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.DoFReference");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleDoFReference
entryRuleDoFReference returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getDoFReferenceRule()); }
	 iv_ruleDoFReference=ruleDoFReference 
	 { $current=$iv_ruleDoFReference.current; } 
	 EOF 
;

// Rule DoFReference
ruleDoFReference returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_doFIdentifier_0_0=RULE_STRING
		{
			newLeafNode(lv_doFIdentifier_0_0, grammarAccess.getDoFReferenceAccess().getDoFIdentifierSTRINGTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getDoFReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"doFIdentifier",
        		lv_doFIdentifier_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFReferenceAccess().getDoFAliasClauseAliasClauseParserRuleCall_1_0()); 
	    }
		lv_doFAliasClause_1_0=ruleAliasClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFReferenceRule());
	        }
       		set(
       			$current, 
       			"doFAliasClause",
        		lv_doFAliasClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.AliasClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
(
		{ 
	        newCompositeNode(grammarAccess.getDoFReferenceAccess().getDoFVariationClauseConfigurationPropertiesClauseParserRuleCall_2_0_0()); 
	    }
		lv_doFVariationClause_2_1=ruleConfigurationPropertiesClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFReferenceRule());
	        }
       		set(
       			$current, 
       			"doFVariationClause",
        		lv_doFVariationClause_2_1, 
        		"tools.descartes.dql.lang.DescartesQL.ConfigurationPropertiesClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getDoFReferenceAccess().getDoFVariationClauseDoFVariationClauseParserRuleCall_2_0_1()); 
	    }
		lv_doFVariationClause_2_2=ruleDoFVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getDoFReferenceRule());
	        }
       		set(
       			$current, 
       			"doFVariationClause",
        		lv_doFVariationClause_2_2, 
        		"tools.descartes.dql.lang.DescartesQL.DoFVariationClause");
	        afterParserOrEnumRuleCall();
	    }

)

)
)?)
;





// Entry rule entryRuleMetricClause
entryRuleMetricClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricClauseRule()); }
	 iv_ruleMetricClause=ruleMetricClause 
	 { $current=$iv_ruleMetricClause.current; } 
	 EOF 
;

// Rule MetricClause
ruleMetricClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		{ 
	        newCompositeNode(grammarAccess.getMetricClauseAccess().getMetricReferenceMetricReferenceParserRuleCall_0()); 
	    }
		lv_metricReference_0_0=ruleMetricReference		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricClauseRule());
	        }
       		set(
       			$current, 
       			"metricReference",
        		lv_metricReference_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricReference");
	        afterParserOrEnumRuleCall();
	    }

)
)
;





// Entry rule entryRuleAggregateMetricClause
entryRuleAggregateMetricClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getAggregateMetricClauseRule()); }
	 iv_ruleAggregateMetricClause=ruleAggregateMetricClause 
	 { $current=$iv_ruleAggregateMetricClause.current; } 
	 EOF 
;

// Rule AggregateMetricClause
ruleAggregateMetricClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getAggregateMetricClauseAccess().getFunctionStatisticalAggregateTypeEnumRuleCall_0_0()); 
	    }
		lv_function_0_0=ruleStatisticalAggregateType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getAggregateMetricClauseRule());
	        }
       		set(
       			$current, 
       			"function",
        		lv_function_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.StatisticalAggregateType");
	        afterParserOrEnumRuleCall();
	    }

)
)	otherlv_1='(' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getAggregateMetricClauseAccess().getLeftParenthesisKeyword_1());
    }
(
(
(
		{ 
	        newCompositeNode(grammarAccess.getAggregateMetricClauseAccess().getMetricsMetricStarClauseParserRuleCall_2_0_0()); 
	    }
		lv_metrics_2_1=ruleMetricStarClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getAggregateMetricClauseRule());
	        }
       		set(
       			$current, 
       			"metrics",
        		lv_metrics_2_1, 
        		"tools.descartes.dql.lang.DescartesQL.MetricStarClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getAggregateMetricClauseAccess().getMetricsMetricClausesParserRuleCall_2_0_1()); 
	    }
		lv_metrics_2_2=ruleMetricClauses		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getAggregateMetricClauseRule());
	        }
       		set(
       			$current, 
       			"metrics",
        		lv_metrics_2_2, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClauses");
	        afterParserOrEnumRuleCall();
	    }

)

)
)	otherlv_3=')' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getAggregateMetricClauseAccess().getRightParenthesisKeyword_3());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getAggregateMetricClauseAccess().getPropertiesConfigurationPropertiesClauseParserRuleCall_4_0()); 
	    }
		lv_properties_4_0=ruleConfigurationPropertiesClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getAggregateMetricClauseRule());
	        }
       		set(
       			$current, 
       			"properties",
        		lv_properties_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.ConfigurationPropertiesClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleMetricClauses
entryRuleMetricClauses returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricClausesRule()); }
	 iv_ruleMetricClauses=ruleMetricClauses 
	 { $current=$iv_ruleMetricClauses.current; } 
	 EOF 
;

// Rule MetricClauses
ruleMetricClauses returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getMetricClausesAccess().getMetricsMetricClauseParserRuleCall_0_0()); 
	    }
		lv_metrics_0_0=ruleMetricClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricClausesRule());
	        }
       		add(
       			$current, 
       			"metrics",
        		lv_metrics_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getMetricClausesAccess().getCommaKeyword_1_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getMetricClausesAccess().getMetricsMetricClauseParserRuleCall_1_1_0()); 
	    }
		lv_metrics_2_0=ruleMetricClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricClausesRule());
	        }
       		add(
       			$current, 
       			"metrics",
        		lv_metrics_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricClause");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleMetricStarClause
entryRuleMetricStarClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricStarClauseRule()); }
	 iv_ruleMetricStarClause=ruleMetricStarClause 
	 { $current=$iv_ruleMetricStarClause.current; } 
	 EOF 
;

// Rule MetricStarClause
ruleMetricStarClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='*.' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getMetricStarClauseAccess().getAsteriskFullStopKeyword_0());
    }
(
(
		lv_metricName_1_0=RULE_ID
		{
			newLeafNode(lv_metricName_1_0, grammarAccess.getMetricStarClauseAccess().getMetricNameIDTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricStarClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"metricName",
        		lv_metricName_1_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
))
;





// Entry rule entryRuleMetricReference
entryRuleMetricReference returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getMetricReferenceRule()); }
	 iv_ruleMetricReference=ruleMetricReference 
	 { $current=$iv_ruleMetricReference.current; } 
	 EOF 
;

// Rule MetricReference
ruleMetricReference returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_entityReference_0_0=RULE_ID
		{
			newLeafNode(lv_entityReference_0_0, grammarAccess.getMetricReferenceAccess().getEntityReferenceIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"entityReference",
        		lv_entityReference_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)((
(
		lv_seperatorn_1_0=	'.' 
    {
        newLeafNode(lv_seperatorn_1_0, grammarAccess.getMetricReferenceAccess().getSeperatornFullStopKeyword_1_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed($current, "seperatorn", lv_seperatorn_1_0, ".");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getMetricReferenceAccess().getNavigationClauseNavigationClauseParserRuleCall_1_1_0()); 
	    }
		lv_navigationClause_2_0=ruleNavigationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getMetricReferenceRule());
	        }
       		set(
       			$current, 
       			"navigationClause",
        		lv_navigationClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.NavigationClause");
	        afterParserOrEnumRuleCall();
	    }

)
))?(
(
		lv_separator_3_0=	'.' 
    {
        newLeafNode(lv_separator_3_0, grammarAccess.getMetricReferenceAccess().getSeparatorFullStopKeyword_2_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed($current, "separator", lv_separator_3_0, ".");
	    }

)
)(
(
		lv_metricReference_4_0=RULE_ID
		{
			newLeafNode(lv_metricReference_4_0, grammarAccess.getMetricReferenceAccess().getMetricReferenceIDTerminalRuleCall_3_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"metricReference",
        		lv_metricReference_4_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)((
(
		lv_separatorv_5_0=	'.' 
    {
        newLeafNode(lv_separatorv_5_0, grammarAccess.getMetricReferenceAccess().getSeparatorvFullStopKeyword_4_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed($current, "separatorv", lv_separatorv_5_0, ".");
	    }

)
)(
(
		lv_statTypeReference_6_0=RULE_ID
		{
			newLeafNode(lv_statTypeReference_6_0, grammarAccess.getMetricReferenceAccess().getStatTypeReferenceIDTerminalRuleCall_4_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getMetricReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"statTypeReference",
        		lv_statTypeReference_6_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
))?)
;





// Entry rule entryRuleNavigationClause
entryRuleNavigationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getNavigationClauseRule()); }
	 iv_ruleNavigationClause=ruleNavigationClause 
	 { $current=$iv_ruleNavigationClause.current; } 
	 EOF 
;

// Rule NavigationClause
ruleNavigationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
    { 
        newCompositeNode(grammarAccess.getNavigationClauseAccess().getParentClauseParserRuleCall_0()); 
    }
    this_ParentClause_0=ruleParentClause
    { 
        $current = $this_ParentClause_0.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getNavigationClauseAccess().getChildrenClauseParserRuleCall_1()); 
    }
    this_ChildrenClause_1=ruleChildrenClause
    { 
        $current = $this_ChildrenClause_1.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getNavigationClauseAccess().getFindClauseParserRuleCall_2()); 
    }
    this_FindClause_2=ruleFindClause
    { 
        $current = $this_FindClause_2.current; 
        afterParserOrEnumRuleCall();
    }
)
;





// Entry rule entryRuleChildrenClause
entryRuleChildrenClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getChildrenClauseRule()); }
	 iv_ruleChildrenClause=ruleChildrenClause 
	 { $current=$iv_ruleChildrenClause.current; } 
	 EOF 
;

// Rule ChildrenClause
ruleChildrenClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_content_0_0=	'children' 
    {
        newLeafNode(lv_content_0_0, grammarAccess.getChildrenClauseAccess().getContentChildrenKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getChildrenClauseRule());
	        }
       		setWithLastConsumed($current, "content", lv_content_0_0, "children");
	    }

)
)
;





// Entry rule entryRuleParentClause
entryRuleParentClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getParentClauseRule()); }
	 iv_ruleParentClause=ruleParentClause 
	 { $current=$iv_ruleParentClause.current; } 
	 EOF 
;

// Rule ParentClause
ruleParentClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_content_0_0=	'parent' 
    {
        newLeafNode(lv_content_0_0, grammarAccess.getParentClauseAccess().getContentParentKeyword_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getParentClauseRule());
	        }
       		setWithLastConsumed($current, "content", lv_content_0_0, "parent");
	    }

)
)
;





// Entry rule entryRuleFindClause
entryRuleFindClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFindClauseRule()); }
	 iv_ruleFindClause=ruleFindClause 
	 { $current=$iv_ruleFindClause.current; } 
	 EOF 
;

// Rule FindClause
ruleFindClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_start_0_0=	'find(' 
    {
        newLeafNode(lv_start_0_0, grammarAccess.getFindClauseAccess().getStartFindKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFindClauseRule());
	        }
       		setWithLastConsumed($current, "start", lv_start_0_0, "find(");
	    }

)
)(
(
		lv_childName_1_0=RULE_STRING
		{
			newLeafNode(lv_childName_1_0, grammarAccess.getFindClauseAccess().getChildNameSTRINGTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFindClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"childName",
        		lv_childName_1_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)(
(
		lv_end_2_0=	')' 
    {
        newLeafNode(lv_end_2_0, grammarAccess.getFindClauseAccess().getEndRightParenthesisKeyword_2_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFindClauseRule());
	        }
       		setWithLastConsumed($current, "end", lv_end_2_0, ")");
	    }

)
))
;





// Entry rule entryRuleForClause
entryRuleForClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getForClauseRule()); }
	 iv_ruleForClause=ruleForClause 
	 { $current=$iv_ruleForClause.current; } 
	 EOF 
;

// Rule ForClause
ruleForClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'FOR' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getForClauseAccess().getModeFORKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getForClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "FOR");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getForClauseAccess().getEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0()); 
	    }
		lv_entityReferenceClause_1_0=ruleEntityReferenceClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getForClauseRule());
	        }
       		set(
       			$current, 
       			"entityReferenceClause",
        		lv_entityReferenceClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.EntityReferenceClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleEntityReferenceClause
entryRuleEntityReferenceClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getEntityReferenceClauseRule()); }
	 iv_ruleEntityReferenceClause=ruleEntityReferenceClause 
	 { $current=$iv_ruleEntityReferenceClause.current; } 
	 EOF 
;

// Rule EntityReferenceClause
ruleEntityReferenceClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getEntityReferenceClauseAccess().getEntityReferencesEntityReferenceParserRuleCall_0_0()); 
	    }
		lv_entityReferences_0_0=ruleEntityReference		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getEntityReferenceClauseRule());
	        }
       		add(
       			$current, 
       			"entityReferences",
        		lv_entityReferences_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.EntityReference");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getEntityReferenceClauseAccess().getCommaKeyword_1_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getEntityReferenceClauseAccess().getEntityReferencesEntityReferenceParserRuleCall_1_1_0()); 
	    }
		lv_entityReferences_2_0=ruleEntityReference		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getEntityReferenceClauseRule());
	        }
       		add(
       			$current, 
       			"entityReferences",
        		lv_entityReferences_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.EntityReference");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleEntityReference
entryRuleEntityReference returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getEntityReferenceRule()); }
	 iv_ruleEntityReference=ruleEntityReference 
	 { $current=$iv_ruleEntityReference.current; } 
	 EOF 
;

// Rule EntityReference
ruleEntityReference returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=RULE_ID
		{
			newLeafNode(lv_type_0_0, grammarAccess.getEntityReferenceAccess().getTypeIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getEntityReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"type",
        		lv_type_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)?(
(
		lv_identifier_1_0=RULE_STRING
		{
			newLeafNode(lv_identifier_1_0, grammarAccess.getEntityReferenceAccess().getIdentifierSTRINGTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getEntityReferenceRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"identifier",
        		lv_identifier_1_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getEntityReferenceAccess().getAliasAliasClauseParserRuleCall_2_0()); 
	    }
		lv_alias_2_0=ruleAliasClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getEntityReferenceRule());
	        }
       		set(
       			$current, 
       			"alias",
        		lv_alias_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.AliasClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleAliasClause
entryRuleAliasClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getAliasClauseRule()); }
	 iv_ruleAliasClause=ruleAliasClause 
	 { $current=$iv_ruleAliasClause.current; } 
	 EOF 
;

// Rule AliasClause
ruleAliasClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'AS' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getAliasClauseAccess().getModeASKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getAliasClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "AS");
	    }

)
)(
(
		lv_alias_1_0=RULE_ID
		{
			newLeafNode(lv_alias_1_0, grammarAccess.getAliasClauseAccess().getAliasIDTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getAliasClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"alias",
        		lv_alias_1_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
))
;





// Entry rule entryRuleUsingClause
entryRuleUsingClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getUsingClauseRule()); }
	 iv_ruleUsingClause=ruleUsingClause 
	 { $current=$iv_ruleUsingClause.current; } 
	 EOF 
;

// Rule UsingClause
ruleUsingClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'USING' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getUsingClauseAccess().getModeUSINGKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getUsingClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "USING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getUsingClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0()); 
	    }
		lv_modelReference_1_0=ruleModelReferenceClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getUsingClauseRule());
	        }
       		set(
       			$current, 
       			"modelReference",
        		lv_modelReference_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.ModelReferenceClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleWithClause
entryRuleWithClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWithClauseRule()); }
	 iv_ruleWithClause=ruleWithClause 
	 { $current=$iv_ruleWithClause.current; } 
	 EOF 
;

// Rule WithClause
ruleWithClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'WITH' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getWithClauseAccess().getModeWITHKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getWithClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "WITH");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getWithClauseAccess().getModelReferenceModelReferenceClauseParserRuleCall_1_0()); 
	    }
		lv_modelReference_1_0=ruleModelReferenceClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWithClauseRule());
	        }
       		set(
       			$current, 
       			"modelReference",
        		lv_modelReference_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.ModelReferenceClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleModelReferenceClause
entryRuleModelReferenceClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getModelReferenceClauseRule()); }
	 iv_ruleModelReferenceClause=ruleModelReferenceClause 
	 { $current=$iv_ruleModelReferenceClause.current; } 
	 EOF 
;

// Rule ModelReferenceClause
ruleModelReferenceClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getModelReferenceClauseAccess().getFamilyModelFamilyParserRuleCall_0_0()); 
	    }
		lv_family_0_0=ruleModelFamily		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getModelReferenceClauseRule());
	        }
       		set(
       			$current, 
       			"family",
        		lv_family_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.ModelFamily");
	        afterParserOrEnumRuleCall();
	    }

)
)	otherlv_1='@' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getModelReferenceClauseAccess().getCommercialAtKeyword_1());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getModelReferenceClauseAccess().getModelModelLocationParserRuleCall_2_0()); 
	    }
		lv_model_2_0=ruleModelLocation		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getModelReferenceClauseRule());
	        }
       		set(
       			$current, 
       			"model",
        		lv_model_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.ModelLocation");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleModelFamily
entryRuleModelFamily returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getModelFamilyRule()); }
	 iv_ruleModelFamily=ruleModelFamily 
	 { $current=$iv_ruleModelFamily.current; } 
	 EOF 
;

// Rule ModelFamily
ruleModelFamily returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_family_0_0=RULE_ID
		{
			newLeafNode(lv_family_0_0, grammarAccess.getModelFamilyAccess().getFamilyIDTerminalRuleCall_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getModelFamilyRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"family",
        		lv_family_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)
;





// Entry rule entryRuleModelLocation
entryRuleModelLocation returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getModelLocationRule()); }
	 iv_ruleModelLocation=ruleModelLocation 
	 { $current=$iv_ruleModelLocation.current; } 
	 EOF 
;

// Rule ModelLocation
ruleModelLocation returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_location_0_0=RULE_STRING
		{
			newLeafNode(lv_location_0_0, grammarAccess.getModelLocationAccess().getLocationSTRINGTerminalRuleCall_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getModelLocationRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"location",
        		lv_location_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)
;





// Entry rule entryRuleFilterClause
entryRuleFilterClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilterClauseRule()); }
	 iv_ruleFilterClause=ruleFilterClause 
	 { $current=$iv_ruleFilterClause.current; } 
	 EOF 
;

// Rule FilterClause
ruleFilterClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'FILTERED BY' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getFilterClauseAccess().getModeFILTEREDBYKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFilterClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "FILTERED BY");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getFilterClauseAccess().getFilterConditionsFilterConditionClauseParserRuleCall_1_0()); 
	    }
		lv_filterConditions_1_0=ruleFilterConditionClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilterClauseRule());
	        }
       		add(
       			$current, 
       			"filterConditions",
        		lv_filterConditions_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterConditionClause");
	        afterParserOrEnumRuleCall();
	    }

)
)((
(
		{ 
	        newCompositeNode(grammarAccess.getFilterClauseAccess().getFilterConjunctionsFilterConjunctionEnumRuleCall_2_0_0()); 
	    }
		lv_filterConjunctions_2_0=ruleFilterConjunction		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilterClauseRule());
	        }
       		add(
       			$current, 
       			"filterConjunctions",
        		lv_filterConjunctions_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterConjunction");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getFilterClauseAccess().getFilterConditionsFilterConditionClauseParserRuleCall_2_1_0()); 
	    }
		lv_filterConditions_3_0=ruleFilterConditionClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilterClauseRule());
	        }
       		add(
       			$current, 
       			"filterConditions",
        		lv_filterConditions_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterConditionClause");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleFilterConditionClause
entryRuleFilterConditionClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilterConditionClauseRule()); }
	 iv_ruleFilterConditionClause=ruleFilterConditionClause 
	 { $current=$iv_ruleFilterConditionClause.current; } 
	 EOF 
;

// Rule FilterConditionClause
ruleFilterConditionClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'CONDITION' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getFilterConditionClauseAccess().getModeCONDITIONKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFilterConditionClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "CONDITION");
	    }

)
)	otherlv_1='(' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getFilterConditionClauseAccess().getLeftParenthesisKeyword_1());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getFilterConditionClauseAccess().getConditionFilterConditionTypeEnumRuleCall_2_0()); 
	    }
		lv_condition_2_0=ruleFilterConditionType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilterConditionClauseRule());
	        }
       		set(
       			$current, 
       			"condition",
        		lv_condition_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterConditionType");
	        afterParserOrEnumRuleCall();
	    }

)
)	otherlv_3=',' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getFilterConditionClauseAccess().getCommaKeyword_3());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getFilterConditionClauseAccess().getValueFilterConditionValueParserRuleCall_4_0()); 
	    }
		lv_value_4_0=ruleFilterConditionValue		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilterConditionClauseRule());
	        }
       		set(
       			$current, 
       			"value",
        		lv_value_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilterConditionValue");
	        afterParserOrEnumRuleCall();
	    }

)
)	otherlv_5=')' 
    {
    	newLeafNode(otherlv_5, grammarAccess.getFilterConditionClauseAccess().getRightParenthesisKeyword_5());
    }
)
;





// Entry rule entryRuleFilterConditionValue
entryRuleFilterConditionValue returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilterConditionValueRule()); }
	 iv_ruleFilterConditionValue=ruleFilterConditionValue 
	 { $current=$iv_ruleFilterConditionValue.current; } 
	 EOF 
;

// Rule FilterConditionValue
ruleFilterConditionValue returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_value_0_0=RULE_STRING
		{
			newLeafNode(lv_value_0_0, grammarAccess.getFilterConditionValueAccess().getValueSTRINGTerminalRuleCall_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFilterConditionValueRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"value",
        		lv_value_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)
;





// Entry rule entryRuleObserveClause
entryRuleObserveClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getObserveClauseRule()); }
	 iv_ruleObserveClause=ruleObserveClause 
	 { $current=$iv_ruleObserveClause.current; } 
	 EOF 
;

// Rule ObserveClause
ruleObserveClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'OBSERVE' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getObserveClauseAccess().getModeOBSERVEKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getObserveClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "OBSERVE");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getObserveClauseAccess().getObservationObservationClauseParserRuleCall_1_0()); 
	    }
		lv_observation_1_0=ruleObservationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveClauseRule());
	        }
       		set(
       			$current, 
       			"observation",
        		lv_observation_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.ObservationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getObserveClauseAccess().getSampleClauseSampleClauseParserRuleCall_2_0()); 
	    }
		lv_sampleClause_2_0=ruleSampleClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveClauseRule());
	        }
       		set(
       			$current, 
       			"sampleClause",
        		lv_sampleClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.SampleClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?)
;





// Entry rule entryRuleObservationClause
entryRuleObservationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getObservationClauseRule()); }
	 iv_ruleObservationClause=ruleObservationClause 
	 { $current=$iv_ruleObservationClause.current; } 
	 EOF 
;

// Rule ObservationClause
ruleObservationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
    { 
        newCompositeNode(grammarAccess.getObservationClauseAccess().getConnectorTimeUnitClauseParserRuleCall_0()); 
    }
    this_ConnectorTimeUnitClause_0=ruleConnectorTimeUnitClause
    { 
        $current = $this_ConnectorTimeUnitClause_0.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getObservationClauseAccess().getConnectorInstanceReferenceClauseParserRuleCall_1()); 
    }
    this_ConnectorInstanceReferenceClause_1=ruleConnectorInstanceReferenceClause
    { 
        $current = $this_ConnectorInstanceReferenceClause_1.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getObservationClauseAccess().getObserveRelativeClauseParserRuleCall_2()); 
    }
    this_ObserveRelativeClause_2=ruleObserveRelativeClause
    { 
        $current = $this_ObserveRelativeClause_2.current; 
        afterParserOrEnumRuleCall();
    }

    |
    { 
        newCompositeNode(grammarAccess.getObservationClauseAccess().getObserveBetweenClauseParserRuleCall_3()); 
    }
    this_ObserveBetweenClause_3=ruleObserveBetweenClause
    { 
        $current = $this_ObserveBetweenClause_3.current; 
        afterParserOrEnumRuleCall();
    }
)
;





// Entry rule entryRuleSampleClause
entryRuleSampleClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getSampleClauseRule()); }
	 iv_ruleSampleClause=ruleSampleClause 
	 { $current=$iv_ruleSampleClause.current; } 
	 EOF 
;

// Rule SampleClause
ruleSampleClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode_0_0=	'SAMPLED BY' 
    {
        newLeafNode(lv_mode_0_0, grammarAccess.getSampleClauseAccess().getModeSAMPLEDBYKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getSampleClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_0, "SAMPLED BY");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSampleClauseAccess().getDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0()); 
	    }
		lv_durationClause_1_0=ruleRelativeTimeDurationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSampleClauseRule());
	        }
       		add(
       			$current, 
       			"durationClause",
        		lv_durationClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeDurationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getSampleClauseAccess().getDurationClauseRelativeTimeDurationClauseParserRuleCall_2_0()); 
	    }
		lv_durationClause_2_0=ruleRelativeTimeDurationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getSampleClauseRule());
	        }
       		add(
       			$current, 
       			"durationClause",
        		lv_durationClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeDurationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)*)
;





// Entry rule entryRuleConnectorTimeUnitClause
entryRuleConnectorTimeUnitClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConnectorTimeUnitClauseRule()); }
	 iv_ruleConnectorTimeUnitClause=ruleConnectorTimeUnitClause 
	 { $current=$iv_ruleConnectorTimeUnitClause.current; } 
	 EOF 
;

// Rule ConnectorTimeUnitClause
ruleConnectorTimeUnitClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_count_0_0=RULE_INT
		{
			newLeafNode(lv_count_0_0, grammarAccess.getConnectorTimeUnitClauseAccess().getCountINTTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConnectorTimeUnitClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"count",
        		lv_count_0_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)(
(
		lv_timeIndicator_1_0=RULE_ID
		{
			newLeafNode(lv_timeIndicator_1_0, grammarAccess.getConnectorTimeUnitClauseAccess().getTimeIndicatorIDTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConnectorTimeUnitClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"timeIndicator",
        		lv_timeIndicator_1_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
))
;





// Entry rule entryRuleConnectorInstanceReferenceClause
entryRuleConnectorInstanceReferenceClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getConnectorInstanceReferenceClauseRule()); }
	 iv_ruleConnectorInstanceReferenceClause=ruleConnectorInstanceReferenceClause 
	 { $current=$iv_ruleConnectorInstanceReferenceClause.current; } 
	 EOF 
;

// Rule ConnectorInstanceReferenceClause
ruleConnectorInstanceReferenceClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_type_0_0=RULE_ID
		{
			newLeafNode(lv_type_0_0, grammarAccess.getConnectorInstanceReferenceClauseAccess().getTypeIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConnectorInstanceReferenceClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"type",
        		lv_type_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)(
(
		lv_identifier_1_0=RULE_STRING
		{
			newLeafNode(lv_identifier_1_0, grammarAccess.getConnectorInstanceReferenceClauseAccess().getIdentifierSTRINGTerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getConnectorInstanceReferenceClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"identifier",
        		lv_identifier_1_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
))
;





// Entry rule entryRuleObserveRelativeClause
entryRuleObserveRelativeClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getObserveRelativeClauseRule()); }
	 iv_ruleObserveRelativeClause=ruleObserveRelativeClause 
	 { $current=$iv_ruleObserveRelativeClause.current; } 
	 EOF 
;

// Rule ObserveRelativeClause
ruleObserveRelativeClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getObserveRelativeClauseAccess().getDirectionObserveRelativeDirectionTypeEnumRuleCall_0_0()); 
	    }
		lv_direction_0_0=ruleObserveRelativeDirectionType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveRelativeClauseRule());
	        }
       		set(
       			$current, 
       			"direction",
        		lv_direction_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.ObserveRelativeDirectionType");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
(
		{ 
	        newCompositeNode(grammarAccess.getObserveRelativeClauseAccess().getTimeTargetAbsoluteTimeClauseParserRuleCall_1_0_0()); 
	    }
		lv_timeTarget_1_1=ruleAbsoluteTimeClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveRelativeClauseRule());
	        }
       		set(
       			$current, 
       			"timeTarget",
        		lv_timeTarget_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.AbsoluteTimeClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getObserveRelativeClauseAccess().getTimeTargetRelativeTimeClauseParserRuleCall_1_0_1()); 
	    }
		lv_timeTarget_1_2=ruleRelativeTimeClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveRelativeClauseRule());
	        }
       		set(
       			$current, 
       			"timeTarget",
        		lv_timeTarget_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeClause");
	        afterParserOrEnumRuleCall();
	    }

)

)
))
;





// Entry rule entryRuleObserveBetweenClause
entryRuleObserveBetweenClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getObserveBetweenClauseRule()); }
	 iv_ruleObserveBetweenClause=ruleObserveBetweenClause 
	 { $current=$iv_ruleObserveBetweenClause.current; } 
	 EOF 
;

// Rule ObserveBetweenClause
ruleObserveBetweenClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_mode1_0_0=	'BETWEEN' 
    {
        newLeafNode(lv_mode1_0_0, grammarAccess.getObserveBetweenClauseAccess().getMode1BETWEENKeyword_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getObserveBetweenClauseRule());
	        }
       		setWithLastConsumed($current, "mode1", lv_mode1_0_0, "BETWEEN");
	    }

)
)(
(
(
		{ 
	        newCompositeNode(grammarAccess.getObserveBetweenClauseAccess().getStartingTimeAbsoluteTimeClauseParserRuleCall_1_0_0()); 
	    }
		lv_startingTime_1_1=ruleAbsoluteTimeClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveBetweenClauseRule());
	        }
       		set(
       			$current, 
       			"startingTime",
        		lv_startingTime_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.AbsoluteTimeClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getObserveBetweenClauseAccess().getStartingTimeRelativeTimeWithSignClauseParserRuleCall_1_0_1()); 
	    }
		lv_startingTime_1_2=ruleRelativeTimeWithSignClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveBetweenClauseRule());
	        }
       		set(
       			$current, 
       			"startingTime",
        		lv_startingTime_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeWithSignClause");
	        afterParserOrEnumRuleCall();
	    }

)

)
)(
(
		lv_mode2_2_0=	'AND' 
    {
        newLeafNode(lv_mode2_2_0, grammarAccess.getObserveBetweenClauseAccess().getMode2ANDKeyword_2_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getObserveBetweenClauseRule());
	        }
       		setWithLastConsumed($current, "mode2", lv_mode2_2_0, "AND");
	    }

)
)(
(
(
		{ 
	        newCompositeNode(grammarAccess.getObserveBetweenClauseAccess().getEndingTimeAbsoluteTimeClauseParserRuleCall_3_0_0()); 
	    }
		lv_endingTime_3_1=ruleAbsoluteTimeClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveBetweenClauseRule());
	        }
       		set(
       			$current, 
       			"endingTime",
        		lv_endingTime_3_1, 
        		"tools.descartes.dql.lang.DescartesQL.AbsoluteTimeClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getObserveBetweenClauseAccess().getEndingTimeRelativeTimeWithSignClauseParserRuleCall_3_0_1()); 
	    }
		lv_endingTime_3_2=ruleRelativeTimeWithSignClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getObserveBetweenClauseRule());
	        }
       		set(
       			$current, 
       			"endingTime",
        		lv_endingTime_3_2, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeWithSignClause");
	        afterParserOrEnumRuleCall();
	    }

)

)
))
;





// Entry rule entryRuleRelativeTimeWithSignClause
entryRuleRelativeTimeWithSignClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getRelativeTimeWithSignClauseRule()); }
	 iv_ruleRelativeTimeWithSignClause=ruleRelativeTimeWithSignClause 
	 { $current=$iv_ruleRelativeTimeWithSignClause.current; } 
	 EOF 
;

// Rule RelativeTimeWithSignClause
ruleRelativeTimeWithSignClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getRelativeTimeWithSignClauseAccess().getSignRelativeTimeSignTypeEnumRuleCall_0_0()); 
	    }
		lv_sign_0_0=ruleRelativeTimeSignType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getRelativeTimeWithSignClauseRule());
	        }
       		set(
       			$current, 
       			"sign",
        		lv_sign_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeSignType");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getRelativeTimeWithSignClauseAccess().getTimeClauseRelativeTimeClauseParserRuleCall_1_0()); 
	    }
		lv_timeClause_1_0=ruleRelativeTimeClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getRelativeTimeWithSignClauseRule());
	        }
       		set(
       			$current, 
       			"timeClause",
        		lv_timeClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;









// Entry rule entryRuleAbsoluteTimeClause
entryRuleAbsoluteTimeClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getAbsoluteTimeClauseRule()); }
	 iv_ruleAbsoluteTimeClause=ruleAbsoluteTimeClause 
	 { $current=$iv_ruleAbsoluteTimeClause.current; } 
	 EOF 
;

// Rule AbsoluteTimeClause
ruleAbsoluteTimeClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_timeSpec_0_0=RULE_STRING
		{
			newLeafNode(lv_timeSpec_0_0, grammarAccess.getAbsoluteTimeClauseAccess().getTimeSpecSTRINGTerminalRuleCall_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getAbsoluteTimeClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"timeSpec",
        		lv_timeSpec_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)
;





// Entry rule entryRuleRelativeTimeClause
entryRuleRelativeTimeClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getRelativeTimeClauseRule()); }
	 iv_ruleRelativeTimeClause=ruleRelativeTimeClause 
	 { $current=$iv_ruleRelativeTimeClause.current; } 
	 EOF 
;

// Rule RelativeTimeClause
ruleRelativeTimeClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getRelativeTimeClauseAccess().getDurationClauseRelativeTimeDurationClauseParserRuleCall_0_0()); 
	    }
		lv_durationClause_0_0=ruleRelativeTimeDurationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getRelativeTimeClauseRule());
	        }
       		add(
       			$current, 
       			"durationClause",
        		lv_durationClause_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeDurationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getRelativeTimeClauseAccess().getDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0()); 
	    }
		lv_durationClause_1_0=ruleRelativeTimeDurationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getRelativeTimeClauseRule());
	        }
       		add(
       			$current, 
       			"durationClause",
        		lv_durationClause_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.RelativeTimeDurationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)*)
;





// Entry rule entryRuleRelativeTimeDurationClause
entryRuleRelativeTimeDurationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getRelativeTimeDurationClauseRule()); }
	 iv_ruleRelativeTimeDurationClause=ruleRelativeTimeDurationClause 
	 { $current=$iv_ruleRelativeTimeDurationClause.current; } 
	 EOF 
;

// Rule RelativeTimeDurationClause
ruleRelativeTimeDurationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_duration_0_0=RULE_INT
		{
			newLeafNode(lv_duration_0_0, grammarAccess.getRelativeTimeDurationClauseAccess().getDurationINTTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getRelativeTimeDurationClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"duration",
        		lv_duration_0_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getRelativeTimeDurationClauseAccess().getTimeModifierTimeModifierTypeEnumRuleCall_1_0()); 
	    }
		lv_timeModifier_1_0=ruleTimeModifierType		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getRelativeTimeDurationClauseRule());
	        }
       		set(
       			$current, 
       			"timeModifier",
        		lv_timeModifier_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.TimeModifierType");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleWhatIfQuery
entryRuleWhatIfQuery returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWhatIfQueryRule()); }
	 iv_ruleWhatIfQuery=ruleWhatIfQuery 
	 { $current=$iv_ruleWhatIfQuery.current; } 
	 EOF 
;

// Rule WhatIfQuery
ruleWhatIfQuery returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='WHAT IF' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getWhatIfQueryAccess().getWHATIFKeyword_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getWhatIfVariationWhatIfVariationParserRuleCall_1_0()); 
	    }
		lv_whatIfVariation_1_0=ruleWhatIfVariation		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"whatIfVariation",
        		lv_whatIfVariation_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.WhatIfVariation");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_2='SELECT' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getWhatIfQueryAccess().getSELECTKeyword_2_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getMetricReferenceClausesMetricReferenceClausesParserRuleCall_2_1_0()); 
	    }
		lv_metricReferenceClauses_3_0=ruleMetricReferenceClauses		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"metricReferenceClauses",
        		lv_metricReferenceClauses_3_0, 
        		"tools.descartes.dql.lang.DescartesQL.MetricReferenceClauses");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getForClauseForClauseParserRuleCall_2_2_0()); 
	    }
		lv_forClause_4_0=ruleForClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"forClause",
        		lv_forClause_4_0, 
        		"tools.descartes.dql.lang.DescartesQL.ForClause");
	        afterParserOrEnumRuleCall();
	    }

)
))?(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getFilteringClauseFilteringClauseParserRuleCall_3_0()); 
	    }
		lv_filteringClause_5_0=ruleFilteringClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"filteringClause",
        		lv_filteringClause_5_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilteringClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getDeltaClauseDeltaClauseParserRuleCall_4_0()); 
	    }
		lv_deltaClause_6_0=ruleDeltaClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"deltaClause",
        		lv_deltaClause_6_0, 
        		"tools.descartes.dql.lang.DescartesQL.DeltaClause");
	        afterParserOrEnumRuleCall();
	    }

)
)?(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfQueryAccess().getUsingClauseUsingClauseParserRuleCall_5_0()); 
	    }
		lv_usingClause_7_0=ruleUsingClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfQueryRule());
	        }
       		set(
       			$current, 
       			"usingClause",
        		lv_usingClause_7_0, 
        		"tools.descartes.dql.lang.DescartesQL.UsingClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleDeltaClause
entryRuleDeltaClause returns [String current=null] 
	:
	{ newCompositeNode(grammarAccess.getDeltaClauseRule()); } 
	 iv_ruleDeltaClause=ruleDeltaClause 
	 { $current=$iv_ruleDeltaClause.current.getText(); }  
	 EOF 
;

// Rule DeltaClause
ruleDeltaClause returns [AntlrDatatypeRuleToken current=new AntlrDatatypeRuleToken()] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:

	kw='DELTA' 
    {
        $current.merge(kw);
        newLeafNode(kw, grammarAccess.getDeltaClauseAccess().getDELTAKeyword()); 
    }

    ;





// Entry rule entryRuleWhatIfVariation
entryRuleWhatIfVariation returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWhatIfVariationRule()); }
	 iv_ruleWhatIfVariation=ruleWhatIfVariation 
	 { $current=$iv_ruleWhatIfVariation.current; } 
	 EOF 
;

// Rule WhatIfVariation
ruleWhatIfVariation returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfVariationAccess().getWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_0_0()); 
	    }
		lv_whatIfVariationClause_0_0=ruleWhatIfVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfVariationRule());
	        }
       		add(
       			$current, 
       			"whatIfVariationClause",
        		lv_whatIfVariationClause_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.WhatIfVariationClause");
	        afterParserOrEnumRuleCall();
	    }

)
)(	otherlv_1=',' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getWhatIfVariationAccess().getCommaKeyword_1_0());
    }
(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfVariationAccess().getWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_1_1_0()); 
	    }
		lv_whatIfVariationClause_2_0=ruleWhatIfVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfVariationRule());
	        }
       		add(
       			$current, 
       			"whatIfVariationClause",
        		lv_whatIfVariationClause_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.WhatIfVariationClause");
	        afterParserOrEnumRuleCall();
	    }

)
))*)
;





// Entry rule entryRuleFilteringClause
entryRuleFilteringClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilteringClauseRule()); }
	 iv_ruleFilteringClause=ruleFilteringClause 
	 { $current=$iv_ruleFilteringClause.current; } 
	 EOF 
;

// Rule FilteringClause
ruleFilteringClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='FILTERING' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getFilteringClauseAccess().getFILTERINGKeyword_0());
    }
((
(
		{ 
	        newCompositeNode(grammarAccess.getFilteringClauseAccess().getFilteringRuleFilteringRuleParserRuleCall_1_0_0()); 
	    }
		lv_filteringRule_1_0=ruleFilteringRule		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilteringClauseRule());
	        }
       		set(
       			$current, 
       			"filteringRule",
        		lv_filteringRule_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilteringRule");
	        afterParserOrEnumRuleCall();
	    }

)
)
    |(
(
		{ 
	        newCompositeNode(grammarAccess.getFilteringClauseAccess().getFilteringStrategyFilteringStrategyParserRuleCall_1_1_0()); 
	    }
		lv_filteringStrategy_2_0=ruleFilteringStrategy		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilteringClauseRule());
	        }
       		set(
       			$current, 
       			"filteringStrategy",
        		lv_filteringStrategy_2_0, 
        		"tools.descartes.dql.lang.DescartesQL.FilteringStrategy");
	        afterParserOrEnumRuleCall();
	    }

)
)))
;





// Entry rule entryRuleFilteringStrategy
entryRuleFilteringStrategy returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilteringStrategyRule()); }
	 iv_ruleFilteringStrategy=ruleFilteringStrategy 
	 { $current=$iv_ruleFilteringStrategy.current; } 
	 EOF 
;

// Rule FilteringStrategy
ruleFilteringStrategy returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(
(
		lv_filteringStrategy_0_0=RULE_STRING
		{
			newLeafNode(lv_filteringStrategy_0_0, grammarAccess.getFilteringStrategyAccess().getFilteringStrategySTRINGTerminalRuleCall_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFilteringStrategyRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"filteringStrategy",
        		lv_filteringStrategy_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)
;





// Entry rule entryRuleFilteringRule
entryRuleFilteringRule returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getFilteringRuleRule()); }
	 iv_ruleFilteringRule=ruleFilteringRule 
	 { $current=$iv_ruleFilteringRule.current; } 
	 EOF 
;

// Rule FilteringRule
ruleFilteringRule returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		{ 
	        newCompositeNode(grammarAccess.getFilteringRuleAccess().getFilteringValueVariableValueParserRuleCall_0_0()); 
	    }
		lv_filteringValue_0_0=ruleVariableValue		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getFilteringRuleRule());
	        }
       		set(
       			$current, 
       			"filteringValue",
        		lv_filteringValue_0_0, 
        		"tools.descartes.dql.lang.DescartesQL.VariableValue");
	        afterParserOrEnumRuleCall();
	    }

)
)(
(
		lv_modifier_1_0=	'%' 
    {
        newLeafNode(lv_modifier_1_0, grammarAccess.getFilteringRuleAccess().getModifierPercentSignKeyword_1_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getFilteringRuleRule());
	        }
       		setWithLastConsumed($current, "modifier", lv_modifier_1_0, "\%");
	    }

)
)?)
;





// Entry rule entryRuleWhatIfVariationClause
entryRuleWhatIfVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWhatIfVariationClauseRule()); }
	 iv_ruleWhatIfVariationClause=ruleWhatIfVariationClause 
	 { $current=$iv_ruleWhatIfVariationClause.current; } 
	 EOF 
;

// Rule WhatIfVariationClause
ruleWhatIfVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_variationPoint_0_0=RULE_STRING
		{
			newLeafNode(lv_variationPoint_0_0, grammarAccess.getWhatIfVariationClauseAccess().getVariationPointSTRINGTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getWhatIfVariationClauseRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"variationPoint",
        		lv_variationPoint_0_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfVariationClauseAccess().getValuesWhatIfValueVariationClauseParserRuleCall_1_0()); 
	    }
		lv_values_1_0=ruleWhatIfValueVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfVariationClauseRule());
	        }
       		set(
       			$current, 
       			"values",
        		lv_values_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.WhatIfValueVariationClause");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleWhatIfValueVariationClause
entryRuleWhatIfValueVariationClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getWhatIfValueVariationClauseRule()); }
	 iv_ruleWhatIfValueVariationClause=ruleWhatIfValueVariationClause 
	 { $current=$iv_ruleWhatIfValueVariationClause.current; } 
	 EOF 
;

// Rule WhatIfValueVariationClause
ruleWhatIfValueVariationClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
(	otherlv_0='<' 
    {
    	newLeafNode(otherlv_0, grammarAccess.getWhatIfValueVariationClauseAccess().getLessThanSignKeyword_0());
    }
(
(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseIntervalVariationClauseParserRuleCall_1_0_0()); 
	    }
		lv_variationClause_1_1=ruleIntervalVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_1_1, 
        		"tools.descartes.dql.lang.DescartesQL.IntervalVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseValueVariationClauseParserRuleCall_1_0_1()); 
	    }
		lv_variationClause_1_2=ruleValueVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_1_2, 
        		"tools.descartes.dql.lang.DescartesQL.ValueVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseArithmeticClauseParserRuleCall_1_0_2()); 
	    }
		lv_variationClause_1_3=ruleArithmeticClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_1_3, 
        		"tools.descartes.dql.lang.DescartesQL.ArithmeticClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseVariationInstructionParserRuleCall_1_0_3()); 
	    }
		lv_variationClause_1_4=ruleVariationInstruction		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_1_4, 
        		"tools.descartes.dql.lang.DescartesQL.VariationInstruction");
	        afterParserOrEnumRuleCall();
	    }

)

)
)(	otherlv_2=',' 
    {
    	newLeafNode(otherlv_2, grammarAccess.getWhatIfValueVariationClauseAccess().getCommaKeyword_2_0());
    }
(
(
(
		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseIntervalVariationClauseParserRuleCall_2_1_0_0()); 
	    }
		lv_variationClause_3_1=ruleIntervalVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_3_1, 
        		"tools.descartes.dql.lang.DescartesQL.IntervalVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseValueVariationClauseParserRuleCall_2_1_0_1()); 
	    }
		lv_variationClause_3_2=ruleValueVariationClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_3_2, 
        		"tools.descartes.dql.lang.DescartesQL.ValueVariationClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseArithmeticClauseParserRuleCall_2_1_0_2()); 
	    }
		lv_variationClause_3_3=ruleArithmeticClause		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_3_3, 
        		"tools.descartes.dql.lang.DescartesQL.ArithmeticClause");
	        afterParserOrEnumRuleCall();
	    }

    |		{ 
	        newCompositeNode(grammarAccess.getWhatIfValueVariationClauseAccess().getVariationClauseVariationInstructionParserRuleCall_2_1_0_3()); 
	    }
		lv_variationClause_3_4=ruleVariationInstruction		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getWhatIfValueVariationClauseRule());
	        }
       		add(
       			$current, 
       			"variationClause",
        		lv_variationClause_3_4, 
        		"tools.descartes.dql.lang.DescartesQL.VariationInstruction");
	        afterParserOrEnumRuleCall();
	    }

)

)
)+)*	otherlv_4='>' 
    {
    	newLeafNode(otherlv_4, grammarAccess.getWhatIfValueVariationClauseAccess().getGreaterThanSignKeyword_3());
    }
)
;







// Entry rule entryRuleVariationInstruction
entryRuleVariationInstruction returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getVariationInstructionRule()); }
	 iv_ruleVariationInstruction=ruleVariationInstruction 
	 { $current=$iv_ruleVariationInstruction.current; } 
	 EOF 
;

// Rule VariationInstruction
ruleVariationInstruction returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_variation_0_0=RULE_ID
		{
			newLeafNode(lv_variation_0_0, grammarAccess.getVariationInstructionAccess().getVariationIDTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getVariationInstructionRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"variation",
        		lv_variation_0_0, 
        		"org.eclipse.xtext.common.Terminals.ID");
	    }

)
)(	otherlv_1='(' 
    {
    	newLeafNode(otherlv_1, grammarAccess.getVariationInstructionAccess().getLeftParenthesisKeyword_1_0());
    }
(
(
		lv_argument_2_0=RULE_STRING
		{
			newLeafNode(lv_argument_2_0, grammarAccess.getVariationInstructionAccess().getArgumentSTRINGTerminalRuleCall_1_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getVariationInstructionRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"argument",
        		lv_argument_2_0, 
        		"org.eclipse.xtext.common.Terminals.STRING");
	    }

)
)	otherlv_3=')' 
    {
    	newLeafNode(otherlv_3, grammarAccess.getVariationInstructionAccess().getRightParenthesisKeyword_1_2());
    }
))
;







// Entry rule entryRuleArithmeticClause
entryRuleArithmeticClause returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getArithmeticClauseRule()); }
	 iv_ruleArithmeticClause=ruleArithmeticClause 
	 { $current=$iv_ruleArithmeticClause.current; } 
	 EOF 
;

// Rule ArithmeticClause
ruleArithmeticClause returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
(
		lv_mode_0_1=	'ADD' 
    {
        newLeafNode(lv_mode_0_1, grammarAccess.getArithmeticClauseAccess().getModeADDKeyword_0_0_0());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getArithmeticClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_1, null);
	    }

    |		lv_mode_0_2=	'SUB' 
    {
        newLeafNode(lv_mode_0_2, grammarAccess.getArithmeticClauseAccess().getModeSUBKeyword_0_0_1());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getArithmeticClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_2, null);
	    }

    |		lv_mode_0_3=	'MULTIPLY' 
    {
        newLeafNode(lv_mode_0_3, grammarAccess.getArithmeticClauseAccess().getModeMULTIPLYKeyword_0_0_2());
    }
 
	    {
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getArithmeticClauseRule());
	        }
       		setWithLastConsumed($current, "mode", lv_mode_0_3, null);
	    }

)

)
)(
(
		{ 
	        newCompositeNode(grammarAccess.getArithmeticClauseAccess().getValueVariableValueParserRuleCall_1_0()); 
	    }
		lv_value_1_0=ruleVariableValue		{
	        if ($current==null) {
	            $current = createModelElementForParent(grammarAccess.getArithmeticClauseRule());
	        }
       		set(
       			$current, 
       			"value",
        		lv_value_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.VariableValue");
	        afterParserOrEnumRuleCall();
	    }

)
))
;





// Entry rule entryRuleVariableValue
entryRuleVariableValue returns [EObject current=null] 
	:
	{ newCompositeNode(grammarAccess.getVariableValueRule()); }
	 iv_ruleVariableValue=ruleVariableValue 
	 { $current=$iv_ruleVariableValue.current; } 
	 EOF 
;

// Rule VariableValue
ruleVariableValue returns [EObject current=null] 
    @init { enterRule(); 
    }
    @after { leaveRule(); }:
((
(
		lv_intValue_0_0=RULE_INT
		{
			newLeafNode(lv_intValue_0_0, grammarAccess.getVariableValueAccess().getIntValueINTTerminalRuleCall_0_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getVariableValueRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"intValue",
        		lv_intValue_0_0, 
        		"org.eclipse.xtext.common.Terminals.INT");
	    }

)
)
    |(
(
		lv_doubleValue_1_0=RULE_DOUBLE
		{
			newLeafNode(lv_doubleValue_1_0, grammarAccess.getVariableValueAccess().getDoubleValueDOUBLETerminalRuleCall_1_0()); 
		}
		{
	        if ($current==null) {
	            $current = createModelElement(grammarAccess.getVariableValueRule());
	        }
       		setWithLastConsumed(
       			$current, 
       			"doubleValue",
        		lv_doubleValue_1_0, 
        		"tools.descartes.dql.lang.DescartesQL.DOUBLE");
	    }

)
))
;





// Rule Comparator
ruleComparator returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='<' 
	{
        $current = grammarAccess.getComparatorAccess().getLessEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getComparatorAccess().getLessEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='<=' 
	{
        $current = grammarAccess.getComparatorAccess().getLessEqualEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getComparatorAccess().getLessEqualEnumLiteralDeclaration_1()); 
    }
)
    |(	enumLiteral_2='>' 
	{
        $current = grammarAccess.getComparatorAccess().getGreaterEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_2, grammarAccess.getComparatorAccess().getGreaterEnumLiteralDeclaration_2()); 
    }
)
    |(	enumLiteral_3='>=' 
	{
        $current = grammarAccess.getComparatorAccess().getGreaterEqualEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_3, grammarAccess.getComparatorAccess().getGreaterEqualEnumLiteralDeclaration_3()); 
    }
)
    |(	enumLiteral_4='==' 
	{
        $current = grammarAccess.getComparatorAccess().getEqualEnumLiteralDeclaration_4().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_4, grammarAccess.getComparatorAccess().getEqualEnumLiteralDeclaration_4()); 
    }
));



// Rule Currency
ruleCurrency returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='EUR' 
	{
        $current = grammarAccess.getCurrencyAccess().getEuroEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getCurrencyAccess().getEuroEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='USD' 
	{
        $current = grammarAccess.getCurrencyAccess().getUsDollarEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getCurrencyAccess().getUsDollarEnumLiteralDeclaration_1()); 
    }
));



// Rule FilterConjunction
ruleFilterConjunction returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='AND' 
	{
        $current = grammarAccess.getFilterConjunctionAccess().getANDEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getFilterConjunctionAccess().getANDEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='XOR' 
	{
        $current = grammarAccess.getFilterConjunctionAccess().getXOREnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getFilterConjunctionAccess().getXOREnumLiteralDeclaration_1()); 
    }
)
    |(	enumLiteral_2='OR' 
	{
        $current = grammarAccess.getFilterConjunctionAccess().getOREnumLiteralDeclaration_2().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_2, grammarAccess.getFilterConjunctionAccess().getOREnumLiteralDeclaration_2()); 
    }
));



// Rule FilterConditionType
ruleFilterConditionType returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='INSTANCEOF' 
	{
        $current = grammarAccess.getFilterConditionTypeAccess().getINSTANCEOFEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getFilterConditionTypeAccess().getINSTANCEOFEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='CLASSREGEX' 
	{
        $current = grammarAccess.getFilterConditionTypeAccess().getCLASSREGEXEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getFilterConditionTypeAccess().getCLASSREGEXEnumLiteralDeclaration_1()); 
    }
));



// Rule ObserveRelativeDirectionType
ruleObserveRelativeDirectionType returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='SINCE' 
	{
        $current = grammarAccess.getObserveRelativeDirectionTypeAccess().getSINCEEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getObserveRelativeDirectionTypeAccess().getSINCEEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='NEXT' 
	{
        $current = grammarAccess.getObserveRelativeDirectionTypeAccess().getNEXTEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getObserveRelativeDirectionTypeAccess().getNEXTEnumLiteralDeclaration_1()); 
    }
));



// Rule RelativeTimeSignType
ruleRelativeTimeSignType returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='-' 
	{
        $current = grammarAccess.getRelativeTimeSignTypeAccess().getMINUSEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getRelativeTimeSignTypeAccess().getMINUSEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='+' 
	{
        $current = grammarAccess.getRelativeTimeSignTypeAccess().getPLUSEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getRelativeTimeSignTypeAccess().getPLUSEnumLiteralDeclaration_1()); 
    }
));



// Rule TimeModifierType
ruleTimeModifierType returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='y' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getYEAREnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getTimeModifierTypeAccess().getYEAREnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='m' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getMONTHEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getTimeModifierTypeAccess().getMONTHEnumLiteralDeclaration_1()); 
    }
)
    |(	enumLiteral_2='w' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getWEEKEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_2, grammarAccess.getTimeModifierTypeAccess().getWEEKEnumLiteralDeclaration_2()); 
    }
)
    |(	enumLiteral_3='d' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getDAYEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_3, grammarAccess.getTimeModifierTypeAccess().getDAYEnumLiteralDeclaration_3()); 
    }
)
    |(	enumLiteral_4='h' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getHOUREnumLiteralDeclaration_4().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_4, grammarAccess.getTimeModifierTypeAccess().getHOUREnumLiteralDeclaration_4()); 
    }
)
    |(	enumLiteral_5='M' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getMINUTEEnumLiteralDeclaration_5().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_5, grammarAccess.getTimeModifierTypeAccess().getMINUTEEnumLiteralDeclaration_5()); 
    }
)
    |(	enumLiteral_6='s' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getSECONDEnumLiteralDeclaration_6().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_6, grammarAccess.getTimeModifierTypeAccess().getSECONDEnumLiteralDeclaration_6()); 
    }
)
    |(	enumLiteral_7='S' 
	{
        $current = grammarAccess.getTimeModifierTypeAccess().getMILLISECONDEnumLiteralDeclaration_7().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_7, grammarAccess.getTimeModifierTypeAccess().getMILLISECONDEnumLiteralDeclaration_7()); 
    }
));



// Rule StatisticalAggregateType
ruleStatisticalAggregateType returns [Enumerator current=null] 
    @init { enterRule(); }
    @after { leaveRule(); }:
((	enumLiteral_0='MIN' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getMINEnumLiteralDeclaration_0().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_0, grammarAccess.getStatisticalAggregateTypeAccess().getMINEnumLiteralDeclaration_0()); 
    }
)
    |(	enumLiteral_1='MAX' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getMAXEnumLiteralDeclaration_1().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_1, grammarAccess.getStatisticalAggregateTypeAccess().getMAXEnumLiteralDeclaration_1()); 
    }
)
    |(	enumLiteral_2='GEOMEAN' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getGEOMEANEnumLiteralDeclaration_2().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_2, grammarAccess.getStatisticalAggregateTypeAccess().getGEOMEANEnumLiteralDeclaration_2()); 
    }
)
    |(	enumLiteral_3='N' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getNEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_3, grammarAccess.getStatisticalAggregateTypeAccess().getNEnumLiteralDeclaration_3()); 
    }
)
    |(	enumLiteral_4='SUM' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getSUMEnumLiteralDeclaration_4().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_4, grammarAccess.getStatisticalAggregateTypeAccess().getSUMEnumLiteralDeclaration_4()); 
    }
)
    |(	enumLiteral_5='SUMOFSQUARES' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getSUMOFSQUARESEnumLiteralDeclaration_5().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_5, grammarAccess.getStatisticalAggregateTypeAccess().getSUMOFSQUARESEnumLiteralDeclaration_5()); 
    }
)
    |(	enumLiteral_6='STDDEV' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getSTDDEVEnumLiteralDeclaration_6().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_6, grammarAccess.getStatisticalAggregateTypeAccess().getSTDDEVEnumLiteralDeclaration_6()); 
    }
)
    |(	enumLiteral_7='VAR' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getVAREnumLiteralDeclaration_7().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_7, grammarAccess.getStatisticalAggregateTypeAccess().getVAREnumLiteralDeclaration_7()); 
    }
)
    |(	enumLiteral_8='PERCENTILE' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getPERCENTILEEnumLiteralDeclaration_8().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_8, grammarAccess.getStatisticalAggregateTypeAccess().getPERCENTILEEnumLiteralDeclaration_8()); 
    }
)
    |(	enumLiteral_9='MEAN' 
	{
        $current = grammarAccess.getStatisticalAggregateTypeAccess().getMEANEnumLiteralDeclaration_9().getEnumLiteral().getInstance();
        newLeafNode(enumLiteral_9, grammarAccess.getStatisticalAggregateTypeAccess().getMEANEnumLiteralDeclaration_9()); 
    }
));



RULE_DOUBLE : ('0'|'1'..'9' ('0'..'9')*) '.' ('0'..'9')+;

RULE_ID : '^'? ('a'..'z'|'A'..'Z'|'_') ('a'..'z'|'A'..'Z'|'_'|'0'..'9')*;

RULE_INT : ('0'..'9')+;

RULE_STRING : ('"' ('\\' .|~(('\\'|'"')))* '"'|'\'' ('\\' .|~(('\\'|'\'')))* '\'');

RULE_ML_COMMENT : '/*' ( options {greedy=false;} : . )*'*/';

RULE_SL_COMMENT : '//' ~(('\n'|'\r'))* ('\r'? '\n')?;

RULE_WS : (' '|'\t'|'\r'|'\n')+;

RULE_ANY_OTHER : .;


