/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.whatif.tests.util;

import static org.junit.Assert.fail;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.List;

import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class TestUtil {
	
	public static String listToString(List<String> list) {
		String ret = "";
		boolean firstline = true;
		for (String s: list) {
			if (!firstline)
				ret += "\n";
			else
				firstline = false;
			ret += s;
		}
		return ret;
	}
	
	public static Object[][] loadArrayFromFile(String path) {
		String content = TestUtil.loadFromFile(path);
		String[] lines = content.split("\n");
		Object[][] ret = new Object[lines.length][4];
		for (int i = 0; i < lines.length; i++) {
			String[] values = lines[i].split(" ");
			ret[i][0] = values[0];
			ret[i][1] = values[1];
			ret[i][2] = Double.valueOf(values[2]);
			ret[i][3] = Double.valueOf(values[3]);
		}
		return ret;
	}
	
	public static Double getValueOf(EntityMapping mapping, String resourceName, String metricName) {
		for (Entity r : mapping.getEntities())
			if (r.getIdentifier().equals(resourceName))
				return getValueOf(r, metricName);
		throw new IllegalStateException("There is no resource with the name " + resourceName);
	}
	
	private static Double getValueOf(Entity r, String metricName) {
		for (Probe probe: r.getProbes())
			if (probe.getMetricName().equals(metricName) && probe instanceof DecimalResult) {
				DecimalResult dr = (DecimalResult)probe;
				return Double.valueOf(dr.getValue().toString());
			}
		return null;
	}
	
	public static String loadFromFile(String path) {
	    try {
			return new String(Files.readAllBytes(Paths.get(path)));
		} catch (IOException e) {
			e.printStackTrace();
			fail("Couldn't read file!");
			return "";
		}
	}
	
	public static void saveToFile(String path, String content) {
		try {
			Files.write( Paths.get(path), content.getBytes());
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	public static boolean contentCompare(String s1, String s2) {
		s1 = s1.replaceAll("\\s", "");
		s2 = s2.replaceAll("\\s", "");
		return s1.equals(s2);
	}
}
