/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.export.svg;

import java.awt.Rectangle;
import java.io.File;
import java.io.IOException;

import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.graphics2d.svg.SVGGraphics2D;
import org.jfree.graphics2d.svg.SVGUtils;

import tools.descartes.pavo.controller.IExportController;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.view.ExportDialogFrame;;

/**
 * Export controller extension using the PAVO ExtensionPoint. 
 * The exported file is of type SVG with the width and height taken from the user interaction with the GUI
 * 
 * @author Maximilian König <max.c.koenig@t-online.de>
 * @since 2016
 */

public class SVGExportController implements IExportController {

	


	@Override
	public void export(File file, JFreeChart chart, ResultContainerPavo result) {
		SVGGraphics2D g2 = new SVGGraphics2D(ExportDialogFrame.widthStatic, ExportDialogFrame.heightStatic);
		Rectangle r = new Rectangle(0, 0, ExportDialogFrame.widthStatic, ExportDialogFrame.heightStatic);
		chart.draw(g2, r);
		File f = new File(file.getPath());
		try {
			SVGUtils.writeToSVG(f, g2.getSVGElement());
		
		} catch (IOException e) {
			e.printStackTrace();
		}
		
	}

	@Override
	public String getStringForCombo() {
		return new String("SVG Export");
	}

	@Override
	public String getIdentifier() {
		return new String("SVG Export");
	}
	
	@Override
	public File updatePathToSuffix(File file) {
		String name = file.getPath();
		if (name.length() < 3 || !name.substring(name.length() - 3, name.length()).equals("svg")) {
			return new File(name + ".svg");
		} else {
			return file;
		}
	}


}