/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.controller;


import java.io.File;
import org.jfree.chart.JFreeChart;
import tools.descartes.pavo.result.*;

/**
 * Interface for all export Extensions for the ExtensionPoint of this package
 * 
 * @author Maximilian König <max.c.koenig@t-online.de>
 * @since 2016
 * @see tools.descartes.pavo.export
 */
public interface IExportController {


	/**
	 *	Method to export a shown diagram
	 *
	 * @param file file location where the exported chart shall be saved
	 * @param chart chart to export
	 * @param result result shown in chart
	 */
	public void export(File file, JFreeChart chart, ResultContainerPavo result);

	
	/**
	 * @return String to show in the export combo box in the export view
	 */
	public String getStringForCombo();
	
	
	/**
	 * @return String as Identifier for this Export Controller (same result as getStringForCombo)
	 */
	public String getIdentifier();
	
	
	/**
	 * Method to add the suffix for the current export if the file does not contain it yet
	 * @param file File to check
	 * @return updated file 
	 */
	public File updatePathToSuffix(File file);

}