/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.LinkedList;

import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYBubbleRenderer;
import org.jfree.chart.renderer.xy.XYItemRenderer;
import org.jfree.data.DomainOrder;
import org.jfree.data.general.DatasetChangeListener;
import org.jfree.data.general.DatasetGroup;
import org.jfree.data.xy.XYZDataset;

import tools.descartes.pavo.controller.VisualizationController;
import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.ValueResultPavo;
import tools.descartes.pavo.util.dof;

/**
 *  * Class to visualise the current result as BubbleChart if possible. Can visualise
 * results constiting out at least 3 series of values. Removing the confidence
 * button and adding three dropdown lists for configure the x, y and z series
 * for the BubbleChart buttons
 * 
 * @author Maximilian König <max.c.koenig@t-online.de>
 * @since 2016
 */
public class BubbleChart extends AbstractVisualizationType implements IVisualizationType {

	private JComboBox<String> comboX;
	private JComboBox<String> comboY;
	private String actualX;
	private String actualY;

	private JPanel panelX;
	private JPanel panelY;
	boolean blocker = false;
	private VisualizationController vizControl;
	double sizefactor = 1;
	JSpinner mySpinner;

	LinkedList<String> doflist = new LinkedList<String>();

	// Autoskale the boxes.
	// Werte die eingehen --> x und y scale
	// aktuelle werte range--> from 1 to 100% scale
	// nehme anzahl an x werten
	// Scroller um den faktor zu erhöhen

	public BubbleChart(ResultContainerPavo resultN, VisualizationController vizControl) {

		super(resultN);
		this.vizControl = vizControl;
		if (this.canVisualize()) {
			panelX = new JPanel();
			panelX.setLayout(new FlowLayout());
			panelY = new JPanel();
			panelY.setLayout(new FlowLayout());
			panelX.add(new JLabel("X:"));
			panelY.add(new JLabel("Y:"));
			comboX = new JComboBox<String>();
			comboY = new JComboBox<String>();
			comboX.setToolTipText("X Axis DOF");
			comboY.setToolTipText("Y Axis DOF");

			panelX.add(comboX);
			panelY.add(comboY);



			setActionListeners();
			// erstelle Liste aller Series
			for (AbstractQuantitativeResult r : getResult().getResults()) {
				if (r instanceof ValueResultPavo) {
					{
						for (dof d : ((ValueResultPavo) r).getDofs()) {
							if (!doflist.contains(d.getDofname()))
								doflist.add(d.getDofname());
						}
					}
				}
			}

			blocker = true;
			this.fillComboBoxes(doflist.toArray());
			blocker = false;
		}

	}

	@Override
	public JFreeChart visualize() {
		updateCurrentXYZ();
		XYZDataset dataset = new XYZDataset() {
			public int getSeriesCount() {
				return 1;
			}

			public int getItemCount(int series) {
				return getResult().getResults().size();
			}

			public Number getX(int series, int item) {


				return new Double(getXValue(series, item));
			}

			public double getXValue(int series, int item) {
				// Hier x dof nehmen
				for (dof d : ((ValueResultPavo) getResult().getResults().get(item)).getDofs()) {
					if (d.getDofname().equals(actualX)) {
						return d.getDofvalue();
					}
				}
				return 0;
			}

			public Number getY(int series, int item) {
				return new Double(getYValue(series, item));
			}

			public double getYValue(int series, int item) {
				for (dof d : ((ValueResultPavo) getResult().getResults().get(item)).getDofs()) {
					if (d.getDofname().equals(actualY)) {
						return d.getDofvalue();
					}
				}
				return 0;
			}

			public Number getZ(int series, int item) {
				return new Double(getZValue(series, item));
			}

			public double getZValue(int series, int item) {
				return ((ValueResultPavo) getResult().getResults().get(item)).getValue() * sizefactor;
			}

			public void addChangeListener(DatasetChangeListener listener) {
				// ignore - this dataset never changes
			}

			public void removeChangeListener(DatasetChangeListener listener) {
				// ignore
			}

			public DatasetGroup getGroup() {
				return null;
			}

			public void setGroup(DatasetGroup group) {
				// ignore
			}

			@SuppressWarnings("rawtypes")
			public Comparable getSeriesKey(int series) {
				return getResult().getMetric();
			}

			@SuppressWarnings("rawtypes")
			public int indexOf(Comparable seriesKey) {
				return 0;
			}

			public DomainOrder getDomainOrder() {
				return DomainOrder.ASCENDING;
			}
		};
		JFreeChart jfreechart = ChartFactory.createBubbleChart("", this.actualX, this.actualY,
				dataset, PlotOrientation.HORIZONTAL, true, true, false);

		XYPlot plot = (XYPlot) jfreechart.getPlot();
		plot.setRenderer(new XYBubbleRenderer(XYBubbleRenderer.SCALE_ON_DOMAIN_AXIS));// Domain
																						// =
																						// x
		plot.setBackgroundPaint(Color.white);
		plot.setRangeGridlinePaint(Color.lightGray);
		plot.setDomainGridlinePaint(Color.lightGray);
		plot.setForegroundAlpha(0.65F);
		XYItemRenderer xyitemrenderer = plot.getRenderer();
		xyitemrenderer.setSeriesPaint(0, Color.blue);
		return jfreechart;
	}

	@Override
	public boolean canVisualize() {
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			if (!(r instanceof ValueResultPavo))
				return false;
			if (!(((ValueResultPavo) r).getDofs().size() == 2))
				return false;
		}
		return true;
	}

	@Override
	public JPanel getEditViewComponent(VisualizationController c) {
		JPanel panel = new JPanel();
		panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));

		updateCurrentXYZ();
		mySpinner = new JSpinner();
		mySpinner.setModel(new SpinnerNumberModel(sizefactor, 0.1, 1000, 0.1));
		mySpinner.addChangeListener(new ChangeListener() {

			@Override
			public void stateChanged(ChangeEvent e) {
				sizefactor = (double) mySpinner.getValue();
				c.updateChart(visualize());

			}
		});
		JPanel spinnerpanel = new JPanel();
		// spinnerpanel.setLayout(new FlowLayout());
		spinnerpanel.add(new JLabel("Size Factor:"));
		spinnerpanel.add(mySpinner);
		panel.add(spinnerpanel);
		panel.add(panelX);
		panel.add(panelY);
		blocker = true;
		this.fillComboBoxes(doflist.toArray());
		blocker = false;
		return panel;
	}

	/**
	 * @return the blockerHeat
	 */
	public boolean isBlocker() {
		return blocker;
	}

	/**
	 * @param blockerHeat
	 *            the blockerHeat to set
	 */
	public void setBlocker(boolean blockerHeat) {
		this.blocker = blockerHeat;
	}

	public void fillComboBoxes(Object[] array) {
		comboX.removeAllItems();
		comboY.removeAllItems();
		for (int i = 0; i < array.length; i++) {
			comboX.addItem(array[i].toString());
			comboY.addItem(array[i].toString());
		}
		comboX.setSelectedIndex(0);
		comboY.setSelectedIndex(1);
	}

	public void updateCurrentXYZ() {
		actualX = comboX.getSelectedItem().toString();
		actualY = comboY.getSelectedItem().toString();
	}

	public void setActionListeners() {

		comboX.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				if (blocker == true) {

				} else {
					blocker = true;
					String now = comboX.getSelectedItem().toString();
					if (comboY.getSelectedItem().toString().equals(now)) {
						comboY.removeAllItems();
						comboY.addItem(actualX);

						for (String s : doflist) {
							if (!s.equals(actualX))
								comboY.addItem(s);
						}
						updateCurrentXYZ();

					}
					blocker = false;
					vizControl.updateChart(visualize());
				}

			}

		});

		comboY.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				if (blocker == true) {

				} else {
					blocker = true;
					String now = comboY.getSelectedItem().toString();
					if (comboX.getSelectedItem().toString().equals(now)) {
						comboX.removeAllItems();
						comboX.addItem(actualY);

						for (String s : doflist) {
							if (!s.equals(actualY))
								comboX.addItem(s);
						}
						updateCurrentXYZ();
					blocker = false;
					vizControl.updateChart(visualize());
				}

			}
			}
		});
	}
}